# Version: April 2024
# R-code written for "Subaqueous bleaching of single-grain K-feldspar luminescence signals" manuscript
# About: Analysis of FS SG MET-pIRIR stimulated luminescence reader output as stored in Risoe .binx files
# Project: NCL-1422, as part of TRAILS funded by NWO grant 17600
# Written by: Marloes Seebregts & Anna-Maartje de Boer

### Section 1: Prepare workspace and load packages

### 1.1 Set working directory and clean R memory ###
setwd("C:/Users/boer304/OneDrive - Wageningen University & Research/PhD/Academic/Rdata/BleachingI") # Define Working Directory
rm(list=ls()) # Delete workspace
graphics.off()  # Close graphic windows

### 1.2 Load necessary packages and functions ###
# Luminescence functions, see https://r-luminescence.org/ for more
if( !("Luminescence" %in% installed.packages()[,1]) )
  install.packages("Luminescence")
library("Luminescence")
if( !("tidyverse" %in% installed.packages()[,1]) )
  install.packages("tidyverse")
library("tidyverse")
if( !("gridExtra" %in% installed.packages()[,1]) )
  install.packages("gridExtra")
library("gridExtra")
if( !("openxlsx" %in% installed.packages()[,1]) )
  install.packages("openxlsx")
library("openxlsx")
if( !("dataPreparation" %in% installed.packages()[,1]) )
  install.packages("dataPreparation")
library("dataPreparation")
if( !("ggridges" %in% installed.packages()[,1]) )
  install.packages("ggridges")
library("ggridges")
if( !("data.table" %in% installed.packages()[,1]) )
  install.packages("data.table")
library("data.table")
if( !("stringr" %in% installed.packages()[,1]) )
  install.packages("stringr")
library("stringr")
if( !("readxl" %in% installed.packages()[,1]) )
  install.packages("readxl")
library("readxl")

# Import altered function of analyse_pIRIRSequence that computes the ylim value differently for plotting the "Sensitivity change" graph
source("FunctionEdit_analyse_pIRIRSequence.R")

# 1.3 NEW FUNCTIONS
# 1.3.1 Remove outliers with IQR (for removing outliers from accepted grains)
# Create detect outlier function
detect_outlier <- function(x) {
  
  # calculate first quantile
  Quantile1 <- quantile(x, probs=.25)
  
  # calculate third quantile
  Quantile3 <- quantile(x, probs=.75)
  
  # calculate inter quartile range
  IQR = Quantile3-Quantile1
  
  # return true or false
  x > Quantile3 + (IQR*1.5) | x < Quantile1 - (IQR*1.5)
}

# Create remove outlier function
remove_outlier <- function(dataframe,
                           columns=names(dataframe)) {
  
  # for loop to traverse in columns vector
  for (col in columns) {
    
    # remove observation if it satisfies outlier function
    dataframe <- dataframe[!detect_outlier(dataframe[[col]]), ]
  }
  
  # return dataframe
  # print("Remove outliers")
  # print(dataframe)
  dataframe
  # list2env(dataframe, envir = .GlobalEnv)
}

calcUncertaintyPropagation = function(exposedGy, exposedGy.Error, irradiatedGy, irradiatedGy.Error) {
  part1 = ( (1/irradiatedGy) * exposedGy.Error )^2
  part2 = ( (-exposedGy / irradiatedGy^2) * irradiatedGy.Error )^2
  uN = sqrt(part1+part2)
  return(uN)
} # Output is fraction, just like the normalized value

#############################################################################################################################################

### Section 2: Define which seq/sample to analyze AND analysis parameters

### 2.1 Insert seq/sample details when you want to analyze a next set of 3 SG discs ###

# What is the name of the sequence excl. binx? Make sure the sequence is stored in "inputdata/binxrisoe/"
binx_name <- "n22mys011b_SG_FS_De_NCL_1422186_1422188_1422189_fixed"
# Insert the sample number that you want to analyze from this .binx file
sample_nr <- "NCL_1422188"
# On which positions are the discs placed on the wheel for this sample? Provide as a list.
pos_nrs <- c(7,9,11)
# In which month was the sequence run in the lab? If multiple months, choose the month with the most reader time.
month_seq <- "2023_01"
# Which signals do you want to analyze? Provide as a list. Don't include operations that are not done on the SG level.
runs_structure <- c("IR50", "pIRIR150", "pIRIR225", "pIRIR290")
# Where can these runs be found in the sequence? Provide as a list.
runs_nrs <- c(3,4,5,6,9,10,11,12) # In our sequences: IR50 is R3/R9, pIRIR150 R4/R10, pIRIR225 R5/R11, pIRIR290 R6/R12

### 2.2 Define analysis parameters (AP) ###
# If you want to run for multiple sets of parameters, extend the tibble later with more rows. Now just 1 scenario.
AP_scenarios <- tibble(
  set_name = c("s01"), # Give parameter(s) a name ; , "s02"
# 2.2.1 Define analysis parameters (AP), which are also available in Risoe Analyst #
# Curve fitting
  curve_fitting = c("EXP"),
# Integration limits
  signal_min = c(6),
  signal_max = c(8),
  background_min = c(40),
  background_max = c(50),
# Parameters
  usepreviousBG_set = c(F), # Choose TRUE if you want to use previous background
  userecycledpts_set = c(F), # Choose TRUE if you want to include recycled points in modelling the dose-response curve
  throughorigin_set = c(T), # Choose TRUE if you want to force the dose-response curve through x=0,y=0
# Error calculations
  ME = c(2.5), # Measurement error in % (in NCL 1.5 for MG, 2.5 for SG)
  MC_iterations = c(1000), # Choose 1000 if script runs smoothly
# "Incorporate error on curve fitting" option not available in R?
# Acceptance Criteria (AC)
# "Use errors when applying criteria" option not available in R -> R doesn't seem to consider AC errors (so to compare with Risoe Analyst, to not check this option there)
  recycl_ratio_lim = c(20), #%
  max_testdose_error = c(20), #%
  max_palaeodose_error = c(NA), #% If 'NA' is chosen, it is not considered in accepting/rejecting
  max_recup = c(NA), # In R only '% of N' option is available
# "Tn signal more than 3 sigma above BG" option not available in R?

# 2.2.2 Define analysis parameters, which are not available in Risoe Analyst #
  useweightedfitting_set = c(F),  # If TRUE is chosen, Lx/Tx errors are taken into account e.g. each regenerative point gets a weight. It didn't seem right to set it to 'TRUE', because higher regenerative doses usually have a higher error exact error, but more regenrative doses in the low region anyway, so curve already more influenced by that region?
  exceed_max_regpoint_set = c(T), # Not really clear from the package documentation what this does. I suppose when FALSE, then rejection if De > max. regen. dose.
  bg_count_distr = c("poisson"), # If "poisson", assumed that the LBG counts are normally distributed. Otherwise "non-poisson" also available.
  weight_type = c("square"), # Used to calculate weighted mean, sd and se based on De+De.Error; "reciprocal" (weight is 1/error), "square" (weight is 1/error^2)
  max_De_Error_Gy = 20 #c(0.5*800*0.092353661) # To remove, manually, accepted grains with enormous errors (max. regen dose * doserate, so +- half of maximum grain that can be measured
)

### 2.3 Define details for tweaking (output) visuals ###
# Package documentation says 15x15 is best, but doesn't work if analyzing more than 2 different signals
visual_settings <- tibble(
  createplots_set = TRUE,
  plots_grainlevel_height = 30,
  plots_grainlevel_width = 15)

### 2.4 Create (monthly) dose rate table for Bambi SG in Gy/s ###
doserate_monthly <- tibble(year_month = c("2022_09", "2022_10", "2022_11", "2022_12", "2023_01", "2023_02"), doserate_Gy_s = c(0.092353661, 0.092168619, 0.091983947, 0.091799646, 0.091615714, 0.091432151), error = NA)
# , doserate_Gy_s = sort(seq(from = 0.0912, to = 0.0924, by = 0.0002), decreasing = TRUE),
#############################################################################################################################################

### Section 3: NOW JUST RUN THE CODE BELOW! No need to change anything here! ###

### 3.1 Import and select reader data ###

# Load .binx file produced by a Risoe DA15 and DA20 TL/OSL reader
reader_output <- read_BIN2R(paste("inputdata/binxrisoe/", binx_name,".binx",sep=""))
# Select records to be analyzed
selection_discs <- Risoe.BINfileData2RLum.Analysis(object=reader_output, pos=pos_nrs, grain=c(1:100), run=runs_nrs, txtProgressBar=T) # Might include: set=c(1:8)
# Create an identifier for the chosen seq + sample combination
seq_sample_name <- paste(vapply(strsplit(binx_name,"_"), `[`, 1, FUN.VALUE=character(1)), "_",sample_nr,sep="")
# Output is for example: "n22mys013b_NCL_1422180"

### 3.2 Start loop, apply analyse_pIRIRSequence() function ###
for (j in 1:nrow(AP_scenarios))
{
  APset_name <- paste("AP", AP_scenarios$set_name[j], sep = "")
  AP <- AP_scenarios[j, , drop = TRUE]
  # Create a .pdf where output graphs of the function can be stored
  filename_plots_grainlevel <- paste("outputdata/manuscript/", seq_sample_name, "_plots_grainlevel_", APset_name, ".pdf",sep="")
  pdf(file = filename_plots_grainlevel, height = visual_settings$plots_grainlevel_height, width = visual_settings$plots_grainlevel_width)
  # To do: instead of palaeodose, plot test dose RC
  # Apply function from lum. package, including curve fitting
  results <- analyse_pIRIRSequence_Marloes( # Plotting error due to infinite ylim range -> fixed in "FunctionEdit_analyse_pIRIRSequence.R" function
    object = selection_discs,
    signal.integral.min = AP$signal_min,
    signal.integral.max = AP$signal_max,
    background.integral.min = AP$background_min,
    background.integral.max = AP$background_max,
    sequence.structure = runs_structure,
    # mode = "interpolation", # Interpolation is the default. They also mention "regenerative" in the package documentation, but doesn't work?
    fit.method = AP$curve_fitting, # Check package documentation p. 251 for more options like EXP or LIN
    fit.weights = AP$useweightedfitting_set, # If TRUE, Lx/Tx errors are taken into account e.g. each regenerative point gets a weight. NCL SG measurement error 2.5%, so weight will always be lower for higher RD's?
    background.count.distribution = AP$bg_count_distr, # Assume that the LBG counts are normally distributed
    use_previousBG = AP$usepreviousBG_set,
    fit.force_through_origin = AP$throughorigin_set,
    fit.includingRepeatedRegPoints = AP$userecycledpts_set,
    #sigmab = ..., # "... calculated assuming the background is constant" used for Lx/Tx error calculation. No value inserted, script will calculate it.
    sig0 = AP$ME/100, # Measurement error (in NCL 1.5 for MG, 2.5 for SG). / 100 because function doesn't want it in %. 1000 is fine from Risoe manual.
    NumberIterations.MC = AP$MC_iterations, # 100 appears to be the default; make higher if script runs smoothly
    rejection.criteria = list(
      recycling.ratio = AP$recycl_ratio_lim,
      recuperation.rate = AP$max_recup, # No 3 options like in Analyst, from Luminescence details: "comparing the Lx/Tx values of the zero regeneration point with the `Ln/Tn` value (the `Lx/Tx ratio of the natural signal)
      testdose.error = AP$max_testdose_error,
      palaeodose.error = AP$max_palaeodose_error, # NA means "Do not consider"
      exceed.max.regpoint = AP$exceed_max_regpoint_set), # I prefer to filter >400s/>800s (higher than max. regenerative dose) out myself afterwards. Once had 'NA'.
    # na.rm = T,
    plot=visual_settings$createplots_set,
    # plot.single = F, # Every graph on a single PDF sheet
  )
  
  # To be able to open .pdf, enter dev.off() x times
  dev.off()
  
  ### 3.3 Explore output of analyse_pIRIRSequence() function ###
  # Save warnings
  warnings_storage <- warnings()
  # Load doserate for this sequence
  doserate <- doserate_monthly$doserate_Gy_s[[which(doserate_monthly$year_month == month_seq)]]
  # Open the main results (De, parameters of fit, related errors, MC, HDPI?, RC.Status, Signal, ...) ; What's HPDI? From MC analysis (68&95)?
  unpacked <- get_RLum(results)%>%as_tibble() #results$data will create the same as get_RLum(results); signal.range.Tx and background.rang.Tx are NA?
  
  ### Add grain numbers, and convert from seconds -> Gy ###
  # Add column with grain numbers (useful for later e.g. interpreting [...]_plots_grainlevel.pdf)
  unpacked$grain.nr = ceiling(as.numeric(rownames(unpacked))/4)
  # Rename columns which will be used later to their unit
  unpacked <- rename(unpacked, De.s = De) %>% rename(De.Error.s = De.Error) %>% rename(De.MC.s = De.MC)
  # Convert from seconds to Gy
  # Could also be done with function Second2Gray() if you want to incorporate doserate error
  unpacked$De.Gy = unpacked$De.s*doserate
  unpacked$De.Error.Gy = unpacked$De.Error.s*doserate # Error on De: De.Error is the standard deviation (=varib within sample) of the MC runs (=standard error (= varib across samples) of De -> where did I find this); see page 95! see calc_Statistics 
  unpacked$De.MC.Gy = unpacked$De.MC.s*doserate
  
  # Manually set OK grains with really large De.Error to FAILED
  for (m in 1:nrow(unpacked)) {
    if (is.finite(unpacked$De.Error.Gy[m])) {
      if (unpacked$De.Error.Gy[m] > AP$max_De_Error_Gy) {
        unpacked$RC.Status[m] <- "FAILED"
      } else {
        unpacked$RC.Status[m] <- unpacked$RC.Status[m]
      }
    }
  }
  
  # Open the numbers 'behind' De ($LnLxTnTx.table) and RC. Status ($rejection.criteria) determination (might compare manually with Analyst)
  results_LnLxTnTx.table <- results$LnLxTnTx.table
  results_LnLxTnTx.table$grain.nr <- ceiling(as.numeric(rownames(results_LnLxTnTx.table))/36)
  # Rejection criteria is missing rows, so same method does not work for assigning grain numbers
  results_rejection.criteria <- results$rejection.criteria
  grainnr_UID <- select(results_LnLxTnTx.table, UID, grain.nr)
  grainnr_UID_unique <- unique(grainnr_UID)
  for (o in 1:nrow(results_rejection.criteria)) {
    UID <- results_rejection.criteria$UID[o]
    grainnr <- grainnr_UID_unique$grain.nr[[which(grainnr_UID_unique$UID == UID)]]
    results_rejection.criteria$grain.nr[o] <- grainnr
  }
  
  # Only select the accepted grains (rejection criteria and LnLxTnTx table won't use anymore)
  accepted <- subset(unpacked, RC.Status=="OK")
  
  # Write away data to xlsx sheet
  unpacked_export <- select(unpacked, grain.nr, RC.Status, Signal, De.Gy, De.Error.Gy, De.MC.Gy, Fit, De.s, De.Error.s, De.MC.s) # Bit less is OK
  sheetnames <- list("De_alsoRejected" = unpacked_export, "De_accepted_allSignals" = accepted, "LnLxTnTx_all" = results_LnLxTnTx.table, 
                     "RejCrit_all" = results_rejection.criteria, "AnalysisParameters" = AP)
  write.xlsx(sheetnames, file = paste("outputdata/manuscript/", seq_sample_name, "_data_grainlevel_", APset_name, ".xlsx",sep=""))
  
  # Sort accepted grains per signal; and calculate statistics
  # Weighted is with considering De.Error.Gy; unweighted without; MC is with considering De.Error in a MC manner
  store_iterations <- list()
  filternames <- c("nofilter", "filter_IQR", "filter_2sd", "filter_3sd", "filter_4sd")
  for (i in 1:length(runs_structure))
  {
    cat(i, "\n")
    store_iterations[[i]] <- list()
    # Start calculating stats
    assign(paste("accepted_", runs_structure[i], sep = ""), as_tibble(subset(accepted, Signal==runs_structure[i]))) #Select only accepted grains
    temp_name <- paste("accepted_", runs_structure[i], sep = "")
    temp_get <- get(paste("accepted_", runs_structure[i], sep = ""))
    write.xlsx(temp_get, file = paste("outputdata/manuscript/", seq_sample_name, "_accepted_input_", runs_structure[i], "_", APset_name, ".xlsx",sep=""), sheetName = "accepted_input", rowNames=T, showNA=F, append=T)
    
    nofilter <- data.frame(temp_get$De.Gy, temp_get$De.Error.Gy)
    if(nrow(temp_get)>0){
      nofilter <- nofilter
    } else{
      nofilter <- data.frame(De.Gy=NA, De.Error.Gy=NA)
    }
    # Four different filters to remove outliers
    IQR_input <- data.frame(temp_get$De.Gy, temp_get$De.Error.Gy) # Bit weird code but function transforms data.frame to data.table :(
    #filter_IQR <- remove_outlier(IQR_input, columns="temp_get.De.Gy") # Remove only De outliers that have been accepted
    if(nrow(temp_get)>0){
      filter_IQR <- remove_outlier(IQR_input, columns="temp_get.De.Gy")
    } else{
      filter_IQR  <- data.frame(De.Gy=NA, De.Error.Gy=NA)
    }
    sd2_input <- data.frame(temp_get$De.Gy, temp_get$De.Error.Gy)
    if(nrow(temp_get)>0){
      filter_2sd <- as.data.frame(remove_sd_outlier(sd2_input, cols="temp_get.De.Gy", n_sigmas=2))
    } else{
      filter_2sd <- data.frame(De.Gy=NA, De.Error.Gy=NA)
    }
    sd3_input <- data.frame(temp_get$De.Gy, temp_get$De.Error.Gy)
    if(nrow(temp_get)>0){
      filter_3sd <- as.data.frame(remove_sd_outlier(sd3_input, cols="temp_get.De.Gy", n_sigmas=3))
    } else{
      filter_3sd <- data.frame(De.Gy=NA, De.Error.Gy=NA)
    }
    sd4_input <- data.frame(temp_get$De.Gy, temp_get$De.Error.Gy)
    if(nrow(temp_get)>0){
      filter_4sd <- as.data.frame(remove_sd_outlier(sd4_input, cols="temp_get.De.Gy", n_sigmas=4))
    } else{
      filter_4sd <- data.frame(De.Gy=NA, De.Error.Gy=NA)
    }
    num.plots <- 4*5
    my.plots <- vector(num.plots, mode='list')
    count1 <- 0
    
    if(nrow(temp_get)>1) { 
      for (filter in filternames)
      {
        cat(i, " ",  filter, "\n")
        # Compute calc_Statistics
        calc_Stat <- calc_Statistics(data=get(filter), weight.calc=AP$weight_type, digits=2, n.MCM=AP$MC_iterations)
        calc_CAM <- calc_CentralDose(data=get(filter), log=T, plot=F) 
        calc_MAM <- calc_MinDose(data=get(filter), sigmab=0.35, plot=F, log=T) 
        
        # Store want you want to keep
        temp_storage <- paste("accepted_", runs_structure[i], "_stats", sep = "")
        temp_data <- assign(temp_storage, 
                            tibble(statistic_name = c("seq_sample_name", "signal", "filter", "n_accepted", "weighted_mean", "weighted_median", "weighted_sd_abs", "weighted_se_abs", 
                                                      "unweighted_mean", "unweighted_median", "unweighted_sd_abs", "unweighted_se_abs",
                                                      "MC_mean", "MC_median", "MC_sd_abs", "MC_se_abs",
                                                      "CAM_De", "CAM_De.Error", "CAM_OD", "CAM_OD.Error",
                                                      "MAM_De", "MAM_De.Error",
                                                      "bootMAM", "bootMAM.Error",
                                                      "skewness", "kurtosis"),
                                   result = as.numeric(list(NA, NA, NA, calc_Stat$weighted$n,
                                                            calc_Stat$weighted$mean,
                                                            calc_Stat$weighted$median,
                                                            calc_Stat$weighted$sd.abs,
                                                            calc_Stat$weighted$se.abs,
                                                            calc_Stat$unweighted$mean,
                                                            calc_Stat$unweighted$median,
                                                            calc_Stat$unweighted$sd.abs,
                                                            calc_Stat$unweighted$se.abs,
                                                            calc_Stat$MCM$mean,
                                                            calc_Stat$MCM$median,
                                                            calc_Stat$MCM$sd.abs,
                                                            calc_Stat$MCM$se.abs,
                                                            round(calc_CAM$summary$de, digits = 2),
                                                            round(calc_CAM$summary$de_err, digits = 2),
                                                            round(calc_CAM$summary$rel_OD, digits = 1),
                                                            round(calc_CAM$summary$rel_OD_err, digits = 1),
                                                            round(calc_MAM$summary$de, digits = 2),
                                                            round(calc_MAM$summary$de_err, digits = 2), NA, NA,
                                                            calc_Stat$weighted$skewness, # Same for unweighted. For MC totally different order of magnitude?
                                                            calc_Stat$weighted$kurtosis)), # Same for unweighted. For MC totally different order of magnitude?)
                                   unit = c(seq_sample_name, temp_name, filter, "-", "Gy", "Gy", "Gy", "Gy", 
                                            "Gy", "Gy", "Gy", "Gy",
                                            "Gy", "Gy", "Gy", "Gy",
                                            "Gy", "Gy", "%", "%",
                                            "Gy", "Gy", "Gy", "Gy",
                                            "-", "-")
                            )
        )
        ## First create the dataframes you want to store
        df_accepted <- data.frame(temp_get.De.Gy = temp_get$De.Gy, temp_get.De.Error.Gy = temp_get$De.Error.Gy)
        df_statistics <- data.frame(temp_data)
        ## Now store those dataframes at the lowest level in the list
        ## Note that you create a sub-list at the same moment
        store_iterations[[i]][[filter]] <- list(accepted=df_accepted, statistics=df_statistics)
        # For writing away plots
        temp_subtitle <- paste(seq_sample_name, "_", temp_name, sep = "")
       # Plots can be extended with more parameters
        stats_overview <- paste("CAM: ", round(calc_CAM$summary$de, digits = 2), "Gy ±" , round(calc_CAM$summary$de_err, digits = 2), " / MAM: ", round(calc_MAM$summary$de, digits = 2), "Gy ±" , round(calc_MAM$summary$de_err, digits = 2), sep="")
        CAM_plot <- paste("CAM ", round(calc_CAM$summary$de, digits = 2), "Gy ±", round(calc_CAM$summary$de_err, digits = 2), sep="")
        MAM_plot <- paste("MAM ", round(calc_MAM$summary$de, digits = 2), "Gy ±", round(calc_MAM$summary$de_err, digits = 2), sep="")
        CAM_Error <- round(calc_CAM$summary$de_err, digits = 2)
        MAM_Error <- round(calc_MAM$summary$de_err, digits = 2)
        CAM_plot2 <- paste("CAM ", round(calc_CAM$summary$de, digits = 2), "±", round(calc_CAM$summary$de_err, digits = 2), sep="")
        MAM_plot2 <- paste("MAM ", round(calc_MAM$summary$de, digits = 2), "±", round(calc_MAM$summary$de_err, digits = 2), sep="")
        plot_RadialPlot(store_iterations[[i]][[filter]]$accepted, zlim=c(0.5,40),line=c(calc_CAM$summary$de, calc_MAM$summary$de), line.col=c("goldenrod3", "darkmagenta"), line.label=c(CAM_plot2, paste(MAM_plot2, "                         ")), centrality="mean", main=paste("De distribution ", seq_sample_name, " ", runs_structure[i], sep=""), pch=16)
        my.plots[[count1+1]] <- recordPlot()
        plot_AbanicoPlot(store_iterations[[i]][[filter]]$accepted, z.0="mean", dispersion="qr", bw=0.1, error.bars=T, line=c(calc_CAM$summary$de, calc_MAM$summary$de), line.col=c("goldenrod3", "darkmagenta"), line.label=c(CAM_plot2, paste(MAM_plot2, "                         ")), centrality="mean", main=paste("De distribution ", seq_sample_name, " ", runs_structure[i], sep=""), pch=16)
        my.plots[[count1+2]] <- recordPlot()
        plot_Histogram(store_iterations[[i]][[filter]]$accepted, se=T, normal_curve=F, summary = c("n"), freq=T, mtext=paste("n = ", calc_Stat$weighted$n, " / ", stats_overview, sep=""), main=paste("Histogram (De) ", seq_sample_name, " ", runs_structure[i], sep="")) # Normal curve is added, based on De values only
        my.plots[[count1+3]] <- recordPlot()
        plot_KDE(store_iterations[[i]][[filter]]$accepted, mtext=paste("n = ", calc_Stat$weighted$n, " ", "/ ", stats_overview, sep=""), main=paste("KDE (De) ", seq_sample_name, " ", runs_structure[i], sep=""))
        my.plots[[count1+4]] <- recordPlot()
        
        count1 <- count1 + 4
        graphics.off()
      }
      
      sheetnames <- list("nofilter_accepted" = store_iterations[[i]][["nofilter"]][["accepted"]], 
                         "nofilter_statistics" = store_iterations[[i]][["nofilter"]][["statistics"]],
                         "filter_IQR_accepted" = store_iterations[[i]][["filter_IQR"]][["accepted"]], 
                         "filter_IQR_statistics" = store_iterations[[i]][["filter_IQR"]][["statistics"]],
                         "filter_2sd_accepted" = store_iterations[[i]][["filter_2sd"]][["accepted"]], 
                         "filter_2sd_statistics" = store_iterations[[i]][["filter_2sd"]][["statistics"]],
                         "filter_3sd_accepted" = store_iterations[[i]][["filter_3sd"]][["accepted"]], 
                         "filter_3sd_statistics" = store_iterations[[i]][["filter_3sd"]][["statistics"]],
                         "filter_4sd_accepted" = store_iterations[[i]][["filter_4sd"]][["accepted"]], 
                         "filter_4sd_statistics" = store_iterations[[i]][["filter_4sd"]][["statistics"]])
      write.xlsx(sheetnames, file = paste("outputdata/manuscript/", seq_sample_name, "_stat_overview_", runs_structure[i], "_", APset_name, ".xlsx",sep=""))
      
      filename_plots_samplelevel <- paste("outputdata/manuscript/", seq_sample_name, "_stats_plots_", runs_structure[i], "_", APset_name, ".pdf",sep="")
      pdf(file = filename_plots_samplelevel, onefile=TRUE)
      for (my.plot in my.plots) {
        replayPlot(my.plot)
      }
      graphics.off()
    }
  }
}
dev.off()

### Section 4: Combine the results per signal for making final bleaching figures
# Sheet 1 = accepted_input (do not use, just for checking what's behind results if things are weird)
# Sheet 2 = accepted_nofilter 
# Sheet 3 = stats_nofilter
# Sheet 4 = accepted_filter_IQR
# Sheet 5 = stats_filter_IQR
# Sheet 6 = accepted_filter_2sd
# Sheet 7 = stats_filter_2sd
# Sheet 8 = accepted_filter_3sd
# Sheet 9 = stats_filter_3sd
# Sheet 10 = accepted_filter_4sd
# Sheet 11 = stats_filter_4sd

# First, for unfiltered (sheet 3)
files <- list.files(path="outputdata/sequenceanalysis", pattern=".xlsx", full.names=TRUE, recursive=FALSE) # Read all files in directory
# Reads a temp file first, delete that one
files <- files[-1]
files #check manually if there are any ~temp files left, if yes > remove them!

# What do we want to read? It will be columns in a table, with each row one sample
# For initializing (tibble gave errors, not sure why, this is a quick and dirty solution)
seq_sample_name <- c()
signal <- c()
n_accepted <- c()
weighted_mean <- c()
weighted_sd_abs <- c()
weighted_se_abs <- c()
unweighted_mean <- c()
unweighted_median <- c()
unweighted_sd_abs <- c()
unweighted_se_abs <- c()
CAM_De <- c()
CAM_De.Error <- c()
CAM_OD <- c()
CAM_OD.Error <- c()
MAM_De <- c()
MAM_De.Error <- c()
bootMAM_De <- c()
bootMAM_De.Error <- c()
# Add bootMAM later from Matlab

# Fill for sheet (e.g. 3 is nofilter)
for (k in 1:length(files)) { # Loop over files
  temp <- read_excel(path=files[k], col_names=T, sheet=3) # For opening again, check if NA's still recognized
  seq_sample_name[k] <- as.character(temp$unit[[which(temp$statistic_name == "seq_sample_name")]])
  signal[k] <- as.character(temp$unit[[which(temp$statistic_name == "signal")]])
  n_accepted[k] <- as.numeric(temp$result[[which(temp$statistic_name == "n_accepted")]])
  weighted_mean[k] <- as.numeric(temp$result[[which(temp$statistic_name == "weighted_mean")]])
  weighted_sd_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "weighted_sd_abs")]])
  weighted_se_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "weighted_se_abs")]])
  unweighted_mean[k] <- as.numeric(temp$result[[which(temp$statistic_name == "unweighted_mean")]])
  unweighted_sd_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "unweighted_sd_abs")]])
  unweighted_se_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "unweighted_se_abs")]])
  CAM_De[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_De")]])
  CAM_De.Error[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_De.Error")]])
  CAM_OD[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_OD")]])
  CAM_OD.Error[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_OD.Error")]])
  MAM_De[k] <- as.numeric(temp$result[[which(temp$statistic_name == "MAM_De")]])
  MAM_De.Error[k] <- as.numeric(temp$result[[which(temp$statistic_name == "MAM_De.Error")]])
  bootMAM_De[k] <- NA
  bootMAM_De.Error[k] <- NA
}
# Combine results from all samples, prepare for plotting
overview_nofilter <- tibble(seq_sample_name = seq_sample_name, signal = signal, n_accepted = n_accepted,
                            weighted_mean = weighted_mean, weighted_sd_abs = weighted_sd_abs, weighted_se_abs = weighted_se_abs,
                            unweighted_mean = unweighted_mean, unweighted_sd_abs = unweighted_sd_abs, unweighted_se_abs = unweighted_se_abs,
                            CAM_De = CAM_De, CAM_De.Error = CAM_De.Error,
                            CAM_OD = CAM_OD, CAM_OD.Error = CAM_OD.Error,
                            MAM_De = MAM_De, MAM_De.Error = MAM_De.Error,
                            bootMAM_De = bootMAM_De, bootMAM_De.Error = bootMAM_De.Error)

# For IQR filter
seq_sample_name <- c()
signal <- c()
n_accepted <- c()
weighted_mean <- c()
weighted_sd_abs <- c()
weighted_se_abs <- c()
unweighted_mean <- c()
unweighted_median <- c()
unweighted_sd_abs <- c()
unweighted_se_abs <- c()
CAM_De <- c()
CAM_De.Error <- c()
CAM_OD <- c()
CAM_OD.Error <- c()
MAM_De <- c()
MAM_De.Error <- c()
bootMAM_De <- c()
bootMAM_De.Error <- c()

for (k in 1:length(files)) { # Loop over files
  temp <- read_excel(path=files[k], col_names=T, sheet=5) # For opening again, check if NA's still recognized
  seq_sample_name[k] <- as.character(temp$unit[[which(temp$statistic_name == "seq_sample_name")]])
  signal[k] <- as.character(temp$unit[[which(temp$statistic_name == "signal")]])
  n_accepted[k] <- as.numeric(temp$result[[which(temp$statistic_name == "n_accepted")]])
  weighted_mean[k] <- as.numeric(temp$result[[which(temp$statistic_name == "weighted_mean")]])
  weighted_sd_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "weighted_sd_abs")]])
  weighted_se_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "weighted_se_abs")]])
  unweighted_mean[k] <- as.numeric(temp$result[[which(temp$statistic_name == "unweighted_mean")]])
  unweighted_sd_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "unweighted_sd_abs")]])
  unweighted_se_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "unweighted_se_abs")]])
  CAM_De[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_De")]])
  CAM_De.Error[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_De.Error")]])
  CAM_OD[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_OD")]])
  CAM_OD.Error[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_OD.Error")]])
  MAM_De[k] <- as.numeric(temp$result[[which(temp$statistic_name == "MAM_De")]])
  MAM_De.Error[k] <- as.numeric(temp$result[[which(temp$statistic_name == "MAM_De.Error")]])
  bootMAM_De[k] <- as.numeric(temp$result[[which(temp$statistic_name == "bootMAM")]])
  bootMAM_De.Error[k] <- as.numeric(temp$result[[which(temp$statistic_name == "bootMAM.Error")]])
}
# Combine results from all samples, prepare for plotting
overview_IQRfilter <- tibble(seq_sample_name = seq_sample_name, signal = signal, n_accepted = n_accepted,
                            weighted_mean = weighted_mean, weighted_sd_abs = weighted_sd_abs, weighted_se_abs = weighted_se_abs,
                            unweighted_mean = unweighted_mean, unweighted_sd_abs = unweighted_sd_abs, unweighted_se_abs = unweighted_se_abs,
                            CAM_De = CAM_De, CAM_De.Error = CAM_De.Error,
                            CAM_OD = CAM_OD, CAM_OD.Error = CAM_OD.Error,
                            MAM_De = MAM_De, MAM_De.Error = MAM_De.Error,
                            bootMAM_De = bootMAM_De, bootMAM_De.Error = bootMAM_De.Error)

# For 2sd filter (unweighted mean)
seq_sample_name <- c()
signal <- c()
n_accepted <- c()
weighted_mean <- c()
weighted_sd_abs <- c()
weighted_se_abs <- c()
unweighted_mean <- c()
unweighted_median <- c()
unweighted_sd_abs <- c()
unweighted_se_abs <- c()
CAM_De <- c()
CAM_De.Error <- c()
CAM_OD <- c()
CAM_OD.Error <- c()
MAM_De <- c()
MAM_De.Error <- c()
bootMAM_De <- c()
bootMAM_De.Error <- c()

for (k in 1:length(files)) { # Loop over files
  temp <- read_excel(path=files[k], col_names=T, sheet=7) # For opening again, check if NA's still recognized
  seq_sample_name[k] <- as.character(temp$unit[[which(temp$statistic_name == "seq_sample_name")]])
  signal[k] <- as.character(temp$unit[[which(temp$statistic_name == "signal")]])
  n_accepted[k] <- as.numeric(temp$result[[which(temp$statistic_name == "n_accepted")]])
  weighted_mean[k] <- as.numeric(temp$result[[which(temp$statistic_name == "weighted_mean")]])
  weighted_sd_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "weighted_sd_abs")]])
  weighted_se_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "weighted_se_abs")]])
  unweighted_mean[k] <- as.numeric(temp$result[[which(temp$statistic_name == "unweighted_mean")]])
  unweighted_sd_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "unweighted_sd_abs")]])
  unweighted_se_abs[k] <- as.numeric(temp$result[[which(temp$statistic_name == "unweighted_se_abs")]])
  CAM_De[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_De")]])
  CAM_De.Error[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_De.Error")]])
  CAM_OD[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_OD")]])
  CAM_OD.Error[k] <- as.numeric(temp$result[[which(temp$statistic_name == "CAM_OD.Error")]])
  MAM_De[k] <- as.numeric(temp$result[[which(temp$statistic_name == "MAM_De")]])
  MAM_De.Error[k] <- as.numeric(temp$result[[which(temp$statistic_name == "MAM_De.Error")]])
  bootMAM_De[k] <- NA
  bootMAM_De.Error[k] <- NA
}
# Combine results from all samples, prepare for plotting
overview_2sdfilter <- tibble(seq_sample_name = seq_sample_name, signal = signal, n_accepted = n_accepted,
                             weighted_mean = weighted_mean, weighted_sd_abs = weighted_sd_abs, weighted_se_abs = weighted_se_abs,
                             unweighted_mean = unweighted_mean, unweighted_sd_abs = unweighted_sd_abs, unweighted_se_abs = unweighted_se_abs,
                             CAM_De = CAM_De, CAM_De.Error = CAM_De.Error,
                             CAM_OD = CAM_OD, CAM_OD.Error = CAM_OD.Error,
                             MAM_De = MAM_De, MAM_De.Error = MAM_De.Error,
                             bootMAM_De = bootMAM_De, bootMAM_De.Error = bootMAM_De.Error)

# Import positions of samples
positions_samples <- read_excel(path="inputdata/binxrisoe/sample_positions_NAP.xlsx", col_names=T, sheet=1) # For opening again, check if NA's still recognized

for (i in 1:nrow(overview_nofilter)) {
  overview_nofilter$position_NAP[i] <- as.numeric(positions_samples$position_NAP.cm[[which(positions_samples$seq_sample_name == overview_nofilter$seq_sample_name[i])]])
}

for (i in 1:nrow(overview_IQRfilter)) {
  overview_IQRfilter$position_NAP[i] <- as.numeric(positions_samples$position_NAP.cm[[which(positions_samples$seq_sample_name == overview_IQRfilter$seq_sample_name[i])]])
}

for (i in 1:nrow(overview_2sdfilter)) {
  overview_2sdfilter$position_NAP[i] <- as.numeric(positions_samples$position_NAP.cm[[which(positions_samples$seq_sample_name == overview_2sdfilter$seq_sample_name[i])]])
}

### Section 5: Normalize data; propagation of uncertainty
# Normalize for all signals
# CAM + ERROR
overview_IQRfilter$normalized_CAM_De <- NA
overview_IQRfilter$normalized_CAM_De <- ifelse(overview_IQRfilter$signal == "accepted_IR50", overview_IQRfilter$CAM_De/overview_IQRfilter$CAM_De[49], overview_IQRfilter$normalized_CAM_De)
overview_IQRfilter$normalized_CAM_De.Error <- NA
overview_IQRfilter$normalized_CAM_De.Error <- ifelse(overview_IQRfilter$signal == "accepted_IR50",
                                                    calcUncertaintyPropagation(exposedGy = overview_IQRfilter$CAM_De, exposedGy.Error = overview_IQRfilter$CAM_De.Error, 
                                                                               irradiatedGy = overview_IQRfilter$CAM_De[49], irradiatedGy.Error = overview_IQRfilter$CAM_De.Error[49]), overview_IQRfilter$normalized_CAM_De.Error)

overview_IQRfilter$normalized_CAM_De <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR150", overview_IQRfilter$CAM_De/overview_IQRfilter$CAM_De[50], overview_IQRfilter$normalized_CAM_De)
overview_IQRfilter$normalized_CAM_De.Error <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR150",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$CAM_De, exposedGy.Error = overview_IQRfilter$CAM_De.Error, 
                                                                                irradiatedGy = overview_IQRfilter$CAM_De[50], irradiatedGy.Error = overview_IQRfilter$CAM_De.Error[50]), overview_IQRfilter$normalized_CAM_De.Error)

overview_IQRfilter$normalized_CAM_De <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR225", overview_IQRfilter$CAM_De/overview_IQRfilter$CAM_De[51], overview_IQRfilter$normalized_CAM_De)
overview_IQRfilter$normalized_CAM_De.Error <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR225",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$CAM_De, exposedGy.Error = overview_IQRfilter$CAM_De.Error, 
                                                                                irradiatedGy = overview_IQRfilter$CAM_De[51], irradiatedGy.Error = overview_IQRfilter$CAM_De.Error[51]), overview_IQRfilter$normalized_CAM_De.Error)

overview_IQRfilter$normalized_CAM_De <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR290", overview_IQRfilter$CAM_De/overview_IQRfilter$CAM_De[52], overview_IQRfilter$normalized_CAM_De)
overview_IQRfilter$normalized_CAM_De.Error <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR290",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$CAM_De, exposedGy.Error = overview_IQRfilter$CAM_De.Error, 
                                                                                irradiatedGy = overview_IQRfilter$CAM_De[52], irradiatedGy.Error = overview_IQRfilter$CAM_De.Error[52]), overview_IQRfilter$normalized_CAM_De.Error)

# BOOTMAM + ERROR
overview_IQRfilter$normalized_bootMAM_De <- NA
overview_IQRfilter$normalized_bootMAM_De <- ifelse(overview_IQRfilter$signal == "accepted_IR50", overview_IQRfilter$bootMAM_De/overview_IQRfilter$bootMAM_De[49], overview_IQRfilter$normalized_bootMAM_De)
overview_IQRfilter$normalized_bootMAM_De.Error <- NA
overview_IQRfilter$normalized_bootMAM_De.Error <- ifelse(overview_IQRfilter$signal == "accepted_IR50",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$bootMAM_De, exposedGy.Error = overview_IQRfilter$bootMAM_De.Error, 
                                                                                irradiatedGy = overview_IQRfilter$bootMAM_De[49], irradiatedGy.Error = overview_IQRfilter$bootMAM_De.Error[49]), overview_IQRfilter$normalized_bootMAM_De.Error)

overview_IQRfilter$normalized_bootMAM_De <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR150", overview_IQRfilter$bootMAM_De/overview_IQRfilter$bootMAM_De[50], overview_IQRfilter$normalized_bootMAM_De)
overview_IQRfilter$normalized_bootMAM_De.Error <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR150",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$bootMAM_De, exposedGy.Error = overview_IQRfilter$bootMAM_De.Error, 
                                                                                irradiatedGy = overview_IQRfilter$bootMAM_De[50], irradiatedGy.Error = overview_IQRfilter$bootMAM_De.Error[50]), overview_IQRfilter$normalized_bootMAM_De.Error)

overview_IQRfilter$normalized_bootMAM_De <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR225", overview_IQRfilter$bootMAM_De/overview_IQRfilter$bootMAM_De[51], overview_IQRfilter$normalized_bootMAM_De)
overview_IQRfilter$normalized_bootMAM_De.Error <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR225",
                                                         calcUncertaintyPropagation(exposedGy = overview_IQRfilter$bootMAM_De, exposedGy.Error = overview_IQRfilter$bootMAM_De.Error, 
                                                                                    irradiatedGy = overview_IQRfilter$bootMAM_De[51], irradiatedGy.Error = overview_IQRfilter$bootMAM_De.Error[51]), overview_IQRfilter$normalized_bootMAM_De.Error)

overview_IQRfilter$normalized_bootMAM_De <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR290", overview_IQRfilter$bootMAM_De/overview_IQRfilter$bootMAM_De[52], overview_IQRfilter$normalized_bootMAM_De)
overview_IQRfilter$normalized_bootMAM_De.Error <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR290",
                                                         calcUncertaintyPropagation(exposedGy = overview_IQRfilter$bootMAM_De, exposedGy.Error = overview_IQRfilter$bootMAM_De.Error, 
                                                                                    irradiatedGy = overview_IQRfilter$bootMAM_De[52], irradiatedGy.Error = overview_IQRfilter$bootMAM_De.Error[52]), overview_IQRfilter$normalized_bootMAM_De.Error)

# UNW. MEAN = SE
overview_IQRfilter$normalized_unweighted_mean <- NA
overview_IQRfilter$normalized_unweighted_mean <- ifelse(overview_IQRfilter$signal == "accepted_IR50", overview_IQRfilter$unweighted_mean/overview_IQRfilter$unweighted_mean[49], overview_IQRfilter$normalized_unweighted_mean)
overview_IQRfilter$normalized_unweighted_se_abs <- NA
overview_IQRfilter$normalized_unweighted_se_abs <- ifelse(overview_IQRfilter$signal == "accepted_IR50",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$unweighted_mean, exposedGy.Error = overview_IQRfilter$unweighted_se_abs, 
                                                                                irradiatedGy = overview_IQRfilter$unweighted_mean[49], irradiatedGy.Error = overview_IQRfilter$unweighted_se_abs[49]), overview_IQRfilter$normalized_unweighted_se_abs)

overview_IQRfilter$normalized_unweighted_mean <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR150", overview_IQRfilter$unweighted_mean/overview_IQRfilter$unweighted_mean[50], overview_IQRfilter$normalized_unweighted_mean)
overview_IQRfilter$normalized_unweighted_se_abs <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR150",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$unweighted_mean, exposedGy.Error = overview_IQRfilter$unweighted_se_abs, 
                                                                                irradiatedGy = overview_IQRfilter$unweighted_mean[50], irradiatedGy.Error = overview_IQRfilter$unweighted_se_abs[50]), overview_IQRfilter$normalized_unweighted_se_abs)

overview_IQRfilter$normalized_unweighted_mean <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR225", overview_IQRfilter$unweighted_mean/overview_IQRfilter$unweighted_mean[51], overview_IQRfilter$normalized_unweighted_mean)
overview_IQRfilter$normalized_unweighted_se_abs <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR225",
                                                          calcUncertaintyPropagation(exposedGy = overview_IQRfilter$unweighted_mean, exposedGy.Error = overview_IQRfilter$unweighted_se_abs, 
                                                                                     irradiatedGy = overview_IQRfilter$unweighted_mean[51], irradiatedGy.Error = overview_IQRfilter$unweighted_se_abs[51]), overview_IQRfilter$normalized_unweighted_se_abs)

overview_IQRfilter$normalized_unweighted_mean <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR290", overview_IQRfilter$unweighted_mean/overview_IQRfilter$unweighted_mean[52], overview_IQRfilter$normalized_unweighted_mean)
overview_IQRfilter$normalized_unweighted_se_abs <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR290",
                                                          calcUncertaintyPropagation(exposedGy = overview_IQRfilter$unweighted_mean, exposedGy.Error = overview_IQRfilter$unweighted_se_abs, 
                                                                                     irradiatedGy = overview_IQRfilter$unweighted_mean[52], irradiatedGy.Error = overview_IQRfilter$unweighted_se_abs[52]), overview_IQRfilter$normalized_unweighted_se_abs)

# OVERDISPERSION
overview_IQRfilter$normalized_CAM_OD <- NA
overview_IQRfilter$normalized_CAM_OD <- ifelse(overview_IQRfilter$signal == "accepted_IR50", overview_IQRfilter$CAM_OD/overview_IQRfilter$CAM_OD[49], overview_IQRfilter$normalized_CAM_OD)
overview_IQRfilter$normalized_CAM_OD.Error <- NA
overview_IQRfilter$normalized_CAM_OD.Error <- ifelse(overview_IQRfilter$signal == "accepted_IR50",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$CAM_OD, exposedGy.Error = overview_IQRfilter$CAM_OD.Error, 
                                                                                irradiatedGy = overview_IQRfilter$CAM_OD[49], irradiatedGy.Error = overview_IQRfilter$CAM_OD.Error[49]), overview_IQRfilter$normalized_CAM_OD.Error)

overview_IQRfilter$normalized_CAM_OD <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR150", overview_IQRfilter$CAM_OD/overview_IQRfilter$CAM_OD[50], overview_IQRfilter$normalized_CAM_OD)
overview_IQRfilter$normalized_CAM_OD.Error <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR150",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$CAM_OD, exposedGy.Error = overview_IQRfilter$CAM_OD.Error, 
                                                                                irradiatedGy = overview_IQRfilter$CAM_OD[50], irradiatedGy.Error = overview_IQRfilter$CAM_OD.Error[50]), overview_IQRfilter$normalized_CAM_OD.Error)

overview_IQRfilter$normalized_CAM_OD <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR225", overview_IQRfilter$CAM_OD/overview_IQRfilter$CAM_OD[51], overview_IQRfilter$normalized_CAM_OD)
overview_IQRfilter$normalized_CAM_OD.Error <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR225",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$CAM_OD, exposedGy.Error = overview_IQRfilter$CAM_OD.Error, 
                                                                                irradiatedGy = overview_IQRfilter$CAM_OD[51], irradiatedGy.Error = overview_IQRfilter$CAM_OD.Error[51]), overview_IQRfilter$normalized_CAM_OD.Error)

overview_IQRfilter$normalized_CAM_OD <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR290", overview_IQRfilter$CAM_OD/overview_IQRfilter$CAM_OD[52], overview_IQRfilter$normalized_CAM_OD)
overview_IQRfilter$normalized_CAM_OD.Error <- ifelse(overview_IQRfilter$signal == "accepted_pIRIR290",
                                                     calcUncertaintyPropagation(exposedGy = overview_IQRfilter$CAM_OD, exposedGy.Error = overview_IQRfilter$CAM_OD.Error, 
                                                                                irradiatedGy = overview_IQRfilter$CAM_OD[52], irradiatedGy.Error = overview_IQRfilter$CAM_OD.Error[52]), overview_IQRfilter$normalized_CAM_OD.Error)

# Make labels for sample numbers
overview_IQRfilter$label = as.character(overview_IQRfilter$seq_sample_name)
overview_IQRfilter$label = str_sub(overview_IQRfilter$label,start=-3)
overview_IQRfilter$label[49] = NA
overview_IQRfilter$label[50] = NA
overview_IQRfilter$label[51] = NA
overview_IQRfilter$label[52] = NA
# <-75 subtidal; 
subtidal <- filter(overview_IQRfilter, position_NAP < -75)

# Not used in the end
subtidal_IR50 <- filter(subtidal, signal == "accepted_IR50")
subtidal_pIRIR150 <- filter(subtidal, signal == "accepted_pIRIR150")
subtidal_pIRIR225 <- filter(subtidal, signal == "accepted_pIRIR225")
subtidal_pIRIR290 <- filter(subtidal, signal == "accepted_pIRIR290")

# IQR_IR50
IQR_IR50 <- filter(overview_IQRfilter, signal == "accepted_IR50")
IQR_pIRIR150 <- filter(overview_IQRfilter, signal == "accepted_pIRIR150")
IQR_pIRIR225 <- filter(overview_IQRfilter, signal == "accepted_pIRIR225")
IQR_pIRIR290 <- filter(overview_IQRfilter, signal == "accepted_pIRIR290")
# Delete starting dose & subaerial for finding trend
IQR_IR50 <- IQR_IR50[-13,]
IQR_IR50 <- IQR_IR50[-15,]
IQR_pIRIR150 <- IQR_pIRIR150[-13,]
IQR_pIRIR150 <- IQR_pIRIR150[-15,]
IQR_pIRIR225 <- IQR_pIRIR225[-13,]
IQR_pIRIR225 <- IQR_pIRIR225[-15,]
IQR_pIRIR290 <- IQR_pIRIR290[-13,]
IQR_pIRIR290 <- IQR_pIRIR290[-15,]

###MANUSCRIPT FIGURES###
#FIGURE 8: normalized CAM vs depth
plot_CAMnorm <- ggplot(overview_IQRfilter, aes(x=normalized_CAM_De, y=position_NAP, xmin=normalized_CAM_De-normalized_CAM_De.Error, xmax=normalized_CAM_De+normalized_CAM_De.Error, group=signal, label=n_accepted)) #+ lm50CAMnormplot + lm150CAMnormplot + lm225CAMnormplot + lm290CAMnormplot
plot_CAMnorm <- plot_CAMnorm + annotate('rect', xmin=0, xmax=1.55, ymin=-300, ymax=-75, alpha=.4, fill='#7BBcE7') + 
  annotate("pointrange", x = 1.45, y = -75, ymin = -75-25, ymax = -75+25, colour = "gray40", size = 0.75, linewidth = 0.5) + 
  annotate("text", x=1.4, y=-187.5, label= "Subtidal", size=5, colour="gray40", angle="90")
plot_CAMnorm <- plot_CAMnorm + annotate('rect', xmin=0, xmax=1.55, ymin=-75, ymax=90, alpha=.2, fill='#7BBCE7') + 
  annotate("pointrange", x = 1.45, y = 90, ymin = 90-25, ymax = 90+25, colour = "gray40", size = 0.75, linewidth = 0.5) + 
  annotate("text", x=1.4, y=8, label= "Intertidal", size=5, colour="gray40", angle="90")
plot_CAMnorm <- plot_CAMnorm + annotate('rect', xmin=0, xmax=1.55, ymin=-305, ymax=-300, alpha=.2, fill='tan4') + 
  annotate("text", x=1.45, y=-290, label= "Seabed", size=5, colour="gray40") +
  annotate("text", x=1.4, y=119, label= "Supratidal", size=5, colour="gray40", angle="90")
plot_CAMnorm <- plot_CAMnorm + annotate('rect', xmin=overview_IQRfilter$normalized_CAM_De[52]-overview_IQRfilter$normalized_CAM_De.Error[52], xmax=overview_IQRfilter$normalized_CAM_De[52]+overview_IQRfilter$normalized_CAM_De.Error[52], ymin=-300, ymax=150, alpha=.1, fill="#8B0000") +
  annotate("text", x=overview_IQRfilter$normalized_CAM_De[49], y=83, label= "Starting dose", angle='90', size=5, colour="gray40")
plot_CAMnorm <- plot_CAMnorm + annotate("text", x=0.05, y=overview_IQRfilter$position_NAP, label=paste("#", overview_IQRfilter$label, sep=""), size=4, colour="gray40") + 
  annotate("text", x=0.05, y=77, label="NCL-1422 #XXX", size=4, colour="gray40", angle="90")
plot_CAMnorm <- plot_CAMnorm + 
  geom_errorbarh(aes(colour=signal),height=0) + 
  geom_point(aes(shape=signal, color=signal, size=signal, fill=signal)) + 
  scale_size_manual(name="Signal", labels=c("IRSL-50","pIRIR-150", "pIRIR-225", "pIRIR290"),
                    values=c(5,5,5,5)) + 
  scale_shape_manual(name="Signal", labels=c("IRSL-50","pIRIR-150", "pIRIR-225", "pIRIR290"),
                     values=c(16,16,16,16)) + 
  scale_color_manual(name="Signal", labels=c("IRSL-50","pIRIR-150", "pIRIR-225", "pIRIR290"),
                     values=c("#FEE391", "#FB9A29", "#CC4C02","#8B0000")) + 
  scale_fill_manual(name="Signal", labels=c("IRSL-50","pIRIR-150", "pIRIR-225", "pIRIR290"),
                    values=c("#FEE391", "#FB9A29", "#CC4C02","#8B0000")) #+ geom_text(hjust=0.5, vjust=0.5, size=2, colour="black")  #,geom_line(method = lm, orientation="y", color="black", alpha=0.3, size=1) +  geom_line(stat="smooth",method = "loess",size = 2, alpha = 0.3, orientation="y") # + scale_size_identity() 
  plot_CAMnorm <- plot_CAMnorm + theme_bw()
plot_CAMnorm <- plot_CAMnorm + scale_x_continuous(name="Normalized CAM", limits=c(0, 1.55), breaks=seq(min(0), max(1.55), by = 0.1), expand = c(0,0)) + 
  scale_y_continuous(name="Vertical position of sample (N.A.P. cm)", limits=c(-305, 150), breaks=seq(min(-350), max(200), by = 50), expand = c (0,0))
plot_CAMnorm <- plot_CAMnorm + 
  theme(panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
      panel.background = element_blank(),
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      axis.text.x=element_text(size = 15),
      axis.ticks.x=element_blank(),
      legend.position = "top",
      axis.text.y=element_text(size=15),
      axis.title.x=element_text(size=15),
      axis.title.y=element_text(size=15),
      axis.ticks = element_line(size=1))
print(plot_CAMnorm)
ggsave(paste("Figure8_normalizedCAMvsdepth.tiff",sep=""), plot = last_plot(), width =10, height =10)
