# Version: April 2024
# R-code written for "Subaqueous bleaching of single-grain K-feldspar luminescence signals" manuscript
# About: Analysis of spectrometer data as stored in .dat files
# Project: NCL-1422, as part of TRAILS funded by NWO grant 17600
# Written by: Marloes Seebregts & Anna-Maartje de Boer

### Section 1: Prepare workspace and load packages
### 1.1 Set working directory and clean R memory ###

setwd("YOURWORKINGDIRECTORYHERE") # Define Working Directory
rm(list=ls()) # Delete workspace
graphics.off()   # Close graphic windows
# dev.off()

### 1.2 Load necessary packages and functions ###
# For working with e.g. tibble, and with ggplot2, see https://www.tidyverse.org/ for more
if( !("tidyverse" %in% installed.packages()[,1]) )
  install.packages("tidyverse")
library("tidyverse")
if( !("gridExtra" %in% installed.packages()[,1]) )
  install.packages("gridExtra")
library("gridExtra")
if( !("dplyr" %in% installed.packages()[,1]) )
  install.packages("dplyr")
library("dplyr")
if( !("pavo" %in% installed.packages()[,1]) )
  install.packages("pavo")
library("pavo")
if( !("lubridate" %in% installed.packages()[,1]) )
  install.packages("lubridate")
library("lubridate")
if( !("RColorBrewer" %in% installed.packages()[,1]) )
  install.packages("RColorBrewer")
library("RColorBrewer")
if( !("patchwork" %in% installed.packages()[,1]) )
  install.packages("patchwork")
library("patchwork")
if( !("colorSpec" %in% installed.packages()[,1]) )
  install.packages("colorSpec")
library("colorSpec")
if( !("ggpmisc" %in% installed.packages()[,1]) )
  install.packages("ggpmisc")
library("ggpmisc")

### 1.3 Own functions to be used
### 1.3.1 Read basic metadata from .dat files based on the first characters of the line.
# It can be used on all 6 different .dat files, the names refer to:
# SAMIP_5052_SAMIP_5052_76F6_ : control file with 3x link to other filenames; 371x (but doesn't include link to calWater and calSky...)
# SAMIP_5052_SAM_82bc_76F6_ : raw spectrum; 371x (seems to be from calWater only looking at IDDevice)
# SAMIP_5052_IP_c073_76F6_ : pressure OR inclination, calibrated; 742x (check IDDataType)

# Where the actual spectra to be analyzed are stored:
# calWater_SAM_82bc_76F6_ : spectrum calibrated water; 371x
# calSky_SAM_82A0_76F6_ : spectrum calibrated sky; 371x

# Function to get the Paramater Value from the .dat file; also works for getting [ATTRIBUTE] values
getParVal = function(filepath, parameterName) { # Insert the filepath string to .dat file, and which parameter to read (e.g. "IDData")
  con <- file(filepath, "r") # It makes a connection with the one .dat file and will make it readable as text
  while (TRUE) { # Open a loop that reads through the lines of the .dat file. "TRUE" just means that it will start. It quits due to 'close' later on.
    line <- readLines(con, n = 1) # n = 1 means it reads all lines separately
    if (startsWith(line, parameterName)) { # Insert the line, and what to look for
      close(con) # If it is true that the parameterName is found, then close the file
      return((strsplit(line, "= ")[[1]])[2]) # and return the part of the line that comes after the delimiter "=". [[1]] has to do with the way it is stored, 2 with the fact that we want to have the part AFTER the "="
    }
    
  }
}

### 1.3.2 Read DATA for calSky and calWater files -> will get table with wavelengths and intensities
getData = function(filepath) { # Insert the filepath and the tibble column to add to
  con <- file(filepath, "r") # It makes a connection with the one .dat file and will make it readable as text
  foundData <- FALSE
  df <- tibble (
    wavelength = numeric(),
    intensity = numeric()
  )
  while (TRUE) { # Open a loop that reads through the lines of the .dat file. "TRUE" just means that it will start. It quits due to 'close' later on.
    line <- readLines(con, n = 1) # n = 1 means it reads all lines separately
    
    # Now, do with if statements things!
    
    if (isTRUE(foundData)) { # If [DATA] is found (see next, set to TRUE), then something is done with all lines behind that [DATA] line, until
      # Unit 1 = $01 $01 Wavelength nm (always the same, do not import)
      # Unit 2 = $03 $06 Intensity mW/(m^2 nm)
      # Unit 3 = empty
      # Unit 4 = empty
      
      if (startsWith(line, "[END] of [DATA]")) { # If this line is reached, it will quit the while loop by return() (and close() the .dat file)
        foundData <- FALSE # Not sure if this is necessary as we won't check any lines after this anyway
        close(con)
        df <- df[-1,] # Remove the line that starts with 0
        return(df)
      } else {
        # print(as.numeric((strsplit(line, " ")[[1]])[3])) # Return only the value for Unit 2 (Intensity); it is [3] because line opens with a " "
        df <- add_row(df, wavelength = as.numeric((strsplit(line, " ")[[1]])[2]), intensity = as.numeric((strsplit(line, " ")[[1]])[3]))
      }
    }
    
    
    if (startsWith(line, "[DATA]")) { # Looping through the lines, once it finds [DATA] it will
      foundData <- TRUE # No need to do anything more now, because data will only be in the next line anyway
    }
  } # End of while() script
}

### 1.3.3 Summarize spectra data per tidal stage and depth-range
### FOR CALWATER DESIGNED ($intensity_fixed and $intensity_normalized_fixed); but calSky is in the normalized
meanSpectrum = function(mega_df, depth_min_m, depth_max_m, tidalStage_input) { # For mega_df, depth_max: 0 cm is everything < 0cm, 20cm is 0-20cm, etc. ; string tS
  # Base to fill
  fill <- tibble (
    wl = numeric(),
    mean_intensity_fixed = numeric(),
    mean_intensity_normalized_fixed = numeric(),
    tidalStage = character(),
    depth_min_m = numeric(),
    depth_max_m = numeric()
  )
  select_tS <- filter(mega_df, tidalStage == tidalStage_input & depth_approx_m > depth_min_m & depth_approx_m <= depth_max_m)
  for (j in 320:950) {
    if (nrow(select_tS) > 0) {
      temp_nm <- filter(select_tS, wavelength == j)
      fill[j-319,"wl"] <- j
      fill$mean_intensity_fixed[j-319] <- mean(temp_nm$intensity_fixed)
      fill$mean_intensity_normalized_fixed[j-319] <- mean(temp_nm$intensity_normalized_fixed)
      fill$tidalStage[j-319] <- tidalStage_input
      fill$depth_min_m[j-319] <- depth_min_m
      fill$depth_max_m[j-319] <- depth_max_m
    } else {
      fill[j-319,"wl"] <- j
      fill$mean_intensity_fixed[j-319] <- NA
      fill$mean_intensity_normalized_fixed[j-319] <- NA
      fill$tidalStage[j-319] <- tidalStage_input
      fill$depth_min_m[j-319] <- depth_min_m
      fill$depth_max_m[j-319] <- depth_max_m
    }  
  }
  return(fill) 
}


### Section 2: Load data
# Note: time in .dat files is UTC time (2 hours earlier than CEST time)
# Store all files names (.dat) in a list of characters (for iteration later)
filepaths <- list.files(path="inputdata/spectra", pattern=".dat", full.names=TRUE, recursive=FALSE)

### 2.1 Make overview of all .dat files and there basic metadata
# Make empty tibble
files_metadata <- tibble(
  filepath = character(),
  IDData = character(),
  IDDevice = character(),
  IDDataType = character(),
  IDDataTypeSub1 = character(),
  DateTime_UTC = character(), # Convert to a CEST DateTime later with ymd_hms() from lubridate
  IDMethodType = character(),
  MethodName = character()
)

# Fill tibble by reading through each .dat file in storage with the getParVal function
for (i in 1:length(filepaths))
{ files_metadata <- add_row(files_metadata, filepath = filepaths[i], IDData = getParVal(filepaths[i], "IDData"),
                            IDDevice = getParVal(filepaths[i], "IDDevice"),
                            IDDataType = getParVal(filepaths[i], "IDDataType"),
                            IDDataTypeSub1 = getParVal(filepaths[i], "IDDataTypeSub1"),
                            DateTime_UTC = getParVal(filepaths[i], "DateTime"),
                            IDMethodType = getParVal(filepaths[i], "IDMethodType"),
                            MethodName = getParVal(filepaths[i], "MethodName"))
}
# Sort all .dat files based on unique DateTime (for linking calSky, calWater and the other files)
files_metadata_withID <- files_metadata %>% group_by(DateTime_UTC) %>% mutate(IDNumber=cur_group_id()) %>% as_tibble()

# Fill fieldwork log later (STILL EMPTY)
field_observations <- tibble (
  filenames = character(),
  specs = integer(),
  startTime = character(),
  endTime = character(),
  tidalStage = character(), 
  above_water = character(),
  within_wave = character(),
  yel_lab = character(),
  notes = character()
)

# Quick link created IDNumbers to fieldwork log (for assigning tidal stage to .dat files)
field_observations_to_files <- tibble (
  startIDNumber = c(1, 34, 100, 156, 200, 239, 272, 316),
  endIDNumber = c(33, 99, 155, 199, 238, 271, 315, 371),
  tidalStage = c("0_Test", "1_HW", "2_HW_HWxLW", "3_HWxLW", "4_HWxLW_LW", "5_LW", "6_LW_LWxHW", "7_LW_HW")
)
files_metadata_all <- files_metadata_withID %>% add_column(tidalStage="NA") # Make empty column to fill

# Link tidal stage to .dat files
for (j in 1:nrow(field_observations_to_files)) {
  
  for (i in 1:nrow(files_metadata_all)) { # Loop through all the .dat files IDNumber's
    if (files_metadata_all$IDNumber[i] >= field_observations_to_files$startIDNumber[j] && files_metadata_all$IDNumber[i] <= field_observations_to_files$endIDNumber[j]) {
      files_metadata_all$tidalStage[i] = field_observations_to_files$tidalStage[j]
    }
  }
  
}
# Make a copy just in case
# In this copy, the calibrated spectra will be added later
spectrometer_data <- files_metadata_all

### Subset tibble with only calSky and calWater
calSky <- subset(spectrometer_data, MethodName=="calSky")
calWater <- subset(spectrometer_data, MethodName=="calWater")

### 2.2 Add actual spectra to the .dat file overview
template <- getData(spectrometer_data$filepath[1]) # For importing the structure, 1 just takes the first row, wil be overwritten to 0:
template$intensity <- 0 # Make all values 0, so it is clear they are filled later on
# Now, fill all cells in the new column "Spectrum" with the template (to make the column a data.frame data type)
calSky$Spectrum[[1]] <- template # Column becomes data.frame. I'm still not sure why it fills all cells, for e.g. string it wouldn't do that
calWater$Spectrum[[1]] <- template

# Now, for every .dat file, update the intensity column in the "Spectrum" column template with the measured data
# For calSky
for (i in 1:nrow(calSky)) {
  spectrum <- getData(calSky$filepath[i]) # Load the wavelength-intensity tibble for one .dat file
  list_lambda_I <- list(wavelength = c(list(spectrum)[[1]]$wavelength), intensity = c(list(spectrum)[[1]]$intensity)) # Convert it into a list of 2
  calSky$Spectrum[[i]][2] <- list_lambda_I$intensity # Change the second part of the list (intensity) in the row of the tibble where the spectrum should be stored
}

# For calWater
for (i in 1:nrow(calWater)) {
  spectrum <- getData(calWater$filepath[i]) # Load the wavelength-intensity tibble for one .dat file
  list_lambda_I <- list(wavelength = c(list(spectrum)[[1]]$wavelength), intensity = c(list(spectrum)[[1]]$intensity)) # Convert it into a list of 2
  calWater$Spectrum[[i]][2] <- list_lambda_I$intensity # Change the second part of the list (intensity) in the row of the tibble where the spectrum should be stored
}

allspectra <- add_row(calSky, calWater)

# Assign IntegrationTime and p999 attributes (exists both in calWater and calSky)
allspectra_att <- allspectra # Copy just in case because previous one takes long to calculate
for (i in 1:nrow(allspectra_att)) {
  allspectra_att[i,"IntegrationTime_ms"] <- as.numeric(getParVal(allspectra_att$filepath[i], "IntegrationTime"))
  allspectra_att[i,"p999"] <- as.numeric(getParVal(allspectra_att$filepath[i], "p999")) # This is a unique number for each .dat file
}

# Assign pressure data (only for calWater)
for (i in 1:nrow(allspectra_att)) {
  if (allspectra_att$MethodName[i]=="calWater") {
    allspectra_att[i,"Pressure"] <- as.numeric(getParVal(allspectra_att$filepath[i], "Pressure"))
    allspectra_att[i,"PressValid"] <- as.numeric(getParVal(allspectra_att$filepath[i], "PressValid"))
  }
}

### 2.3 Transform pressure to meters of depth of spectrometer
rho_salt <- 1023.6 # kg/m^3
g <-9.80665 # m/s^2
allspectra_att$depth_approx_m <- round(allspectra_att$Pressure * 100 * 1000 / (rho_salt*g), digits = 3)
# Check difference with sweet water (just to check sensitivity)
allspectra_att$depth_approx_m_ZOET <- round(allspectra_att$Pressure * 100 * 1000 / (997.0474*g), digits = 3)
plot(allspectra_att$depth_approx_m_ZOET, allspectra_att$depth_approx_m) # Maybe 10cm difference at max.? But ebb/flood doesn't differ that much, I guess?
allspectra_att$depth_approx_m_ZOUTER <- round(allspectra_att$Pressure * 100 * 1000 / (1025*g), digits = 3)
allspectra_att$depth_approx_m_verschildepth <- allspectra_att$depth_approx_m - allspectra_att$depth_approx_m_ZOUTER # maar 5cm max. difference ->
# https://journals.ametsoc.org/view/journals/phoc/38/3/2007jpo3796.1.xml?tab_body=pdf density difference not that much, yay!
# Pressure is in 100 hPa unit -> so the number in Pressure is the same as bar?
# P = p g h -> h = P / (p*g)
# psalt = 1023.6kg/m^3 ; from: https://bluerobotics.com/learn/pressure-depth-calculator/ 
# g = 9.80665 m/s^2

### 2.4 Calculate a normalized spectrum, save it as a new column in the calWater tibble
allspectra_norm <- allspectra_att

for (i in 1:nrow(allspectra_norm)) { # Loop through all rows
  
  if (allspectra_norm$MethodName[i] == "calWater") { # Only do something for calWater i's
    detect_IDNumber <- as.numeric(allspectra_norm$IDNumber[i]) # Detect IDNumber of the found calWater observation
    find_calSky_i <- which(allspectra_norm$IDNumber == detect_IDNumber & allspectra_norm$MethodName == "calSky") # Find loc. of corresponding calSky
    allspectra_norm$Spectrum[[i]]["intensity_normalized"] <- allspectra_norm$Spectrum[[i]]["intensity"] / allspectra_norm$Spectrum[[find_calSky_i]]["intensity"] # Calculate and save new column in calWater spectrum
    allspectra_norm$Spectrum[[i]]["copy_calSky"] <- allspectra_norm$Spectrum[[find_calSky_i]]["intensity"] # Make a copy, easy for later
    # Misschien nog depth (m) toevoegen? Voor color ramp later?
  }  
}
  
### 2.5 Look for abnormal values in copy of the allspectra_norm
allspectra_check <- allspectra_norm # Copy just to be sure
for (i in 1:nrow(allspectra_check)) { # for both calSky and calWater
  # Check for weird depth, only for calWater
  if  (allspectra_check$depth_approx_m[i] <= 0 && allspectra_check$MethodName[i] == "calWater") {
    allspectra_check$depth_under0m[i] <- TRUE
  } else {
    allspectra_check$depth_under0m[i] <- FALSE
  }
  
  # Check for weird intensity (<= 0) for both calSky and calWater
  df_check <- allspectra_check$Spectrum[[i]]["intensity"]
  tellen <- 0
  for (j in 1:nrow(df_check)) { # Check all 631 spectrum numbers
    if (df_check$intensity[j] <= 0) {
      tellen <- tellen + 1
    }
    allspectra_check$count_I_W_under0[i] <- tellen
  }
  
  # Check for weird normalized values, only in calWater records)
  if  (allspectra_check$MethodName[i] == "calWater") {
    df_check2 <- allspectra_check$Spectrum[[i]]["intensity_normalized"]
    tellen2 <- 0
    tellen3 <- 0
    for (j in 1:nrow(df_check2)) { # Check all 631 spectrum numbers
      if (df_check2$intensity_normalized[j] <= 0) {
        tellen2 <- tellen2 + 1
      }
      allspectra_check$count_N_W_under0[i] <- tellen2
      
      if (df_check2$intensity_normalized[j] >= 1) {
        tellen3 <- tellen3 + 1
      }
      allspectra_check$count_N_W_above1[i] <- tellen3 # IDNumber 156&200 can be deleted based on this; also hve depth < 0a
    }   
  } else { # Bij calSky
    allspectra_check$count_N_W_under0[i] <- 0
    allspectra_check$count_N_W_above1[i] <- 0
  }
}

# Find out when there are so many wavelengths below zero per calWater spectrum?
negative <- filter(allspectra_check, count_I_W_under0 > 0)
plot(negative$depth_approx_m, negative$count_I_W_under0)

### 2.6 Subset the data that is needed for further analysis (there is a copy of calSky in the calWater spectra table now!)
calWater_norm <- subset(allspectra_norm, MethodName=="calWater")

### 2.7 Assign color code for depth, make color categories for assigning to depth measurements of spectrometer
colfunc2 <- colorRampPalette(c("#c6E2FF","#00008B"))
color_cat <- tibble (
  sort_min = seq(-0.05, 3.150, by = 0.1), #
  sort_max = seq(0.05, 3.30, by = 0.1),
  color = colfunc2(33), # 33 because 33 categories
  # label = as.numeric(seq(0, 3.2, by = 0.1)) -> for some reason some numbers like 0.3 weren't recognized if searched
  label = c("0.0", "0.1", "0.2", "0.3", "0.4", "0.5", "0.6", "0.7", "0.8", "0.9", "1.0", "1.1", "1.2", "1.3", "1.4", "1.5", "1.6", "1.7", "1.8", "1.9", "2.0", "2.1", "2.2", "2.3", "2.4", "2.5", "2.6", "2.7", "2.8", "2.9", "3.0", "3.1", "3.2")
)

# Give label character() on rounded depth (for some reason linking didn't work with numeric)
for (i in 1:nrow(calWater_norm)) {
  depth <- calWater_norm$depth_approx_m[i]
  for (j in 1:nrow(color_cat)) {
    if (depth >= color_cat$sort_min[j] && depth < color_cat$sort_max[j]) {
      labelx <- color_cat$label[j]
      calWater_norm$label[i] <- labelx
      calWater_norm$color[i] <- color_cat$color[j]
    }
    
  }
}

### 2.8 Delete the two outliers 156&200 as identified above in 2.5
calWater_norm <- calWater_norm[-156,]
calWater_norm <- calWater_norm[-199,] # 200-1 because the other is already deleted; 369 left!

# DELETE shallow depths (reduces noise in graphs); added this line in later stage so delete if error is there
calWater_norm <- filter(calWater_norm, depth_approx_m > 0.049) # Everything lower than 5cm deep deleted

### 2.9.1 Make a mega dataframe with all spectra (except the two as deleted above)
# Make template
build_df <- calWater_norm$Spectrum[[1]]
build_df$DateTime_UTC <- calWater_norm$DateTime_UTC[1]
build_df$IDNumber <- calWater_norm$IDNumber[1]
build_df$tidalStage <- calWater_norm$tidalStage[1]
build_df$depth_approx_m <- calWater_norm$depth_approx_m[1]
build_df$label <- calWater_norm$label[1]
build_df$color <- calWater_norm$color[1]

mega_df <- build_df # Delete the first 631 rows later!

for (i in 2:nrow(calWater_norm)) {
  # Build dataframe
  part_df <- calWater_norm$Spectrum[[i]]
  part_df$DateTime_UTC <- calWater_norm$DateTime_UTC[i]
  part_df$IDNumber <- calWater_norm$IDNumber[i]
  part_df$tidalStage <- calWater_norm$tidalStage[i]
  part_df$depth_approx_m <- calWater_norm$depth_approx_m[i]
  part_df$label <- calWater_norm$label[i]
  part_df$color <- calWater_norm$color[i]
  
  # Add to previous one
  mega_df <- add_row(mega_df, part_df)
  
} # Should have 369 spectra x  631 wavelengths = 232839 rows

# Make copy with nice name
spectra_megabase <- mega_df # Contains 232839 rows! calWater, calSky, normalized, 'fixed' values and metadata for this wl are inside the columns

### Section 3: Make rspec objects per tidal stage (without 156 and 200, but not with < 0 calWater values corrected)
# 3.1.1 PER TIDAL STAGE, FOR CALWATER (W)
for (i in field_observations_to_files$tidalStage) { # tidalStage categories are stored here already
  name <- paste("spectra_W_", i, sep = "") # Used later for finding the table again
  assign(paste("spectra_W_", i, sep = ""), subset(calWater_norm, tidalStage==i)) # Make subset per tidal stage
  # Make empty rspec table to add to in next loop
  empty <- as.rspec(allspectra_att$Spectrum[372][[1]]) # Just a random wavelength-intensity table
  empty$intensity = 0 # Make intenisty zero, template to add to later
  rspec_build <- empty
  
    for (j in 1:nrow(get(name))) { # Loop through all rows of one subset
      select1 <- get(name)$Spectrum[j][[1]] # Get calWater spectrum, including normalized and calSky copy columns
      select2 <- select1[,-4] # Delete calSky column (in this case)
      select3 <- select2[,-3] # Delete normalized column (in this case) ; -2 would be the calWater
      rspec_i <- as.rspec(select3) # Find spectrum for this [i]
      assign(paste("rspec_W_", i, sep = ""), merge(rspec_build, rspec_i)) # Add new one to the old version from previous row
      rspec_build <- get(paste("rspec_W_", i, sep = "")) # Overwrite the old version for the next loop [i]
    }
  # Remove the 0 column needed for initializing
  temp_spec <- get(paste("rspec_W_", i, sep = ""))[,-2]
  assign(paste("rspec_W_", i, sep = ""), temp_spec)
}

# 3.1.2 PER TIDAL STAGE, FOR CALSKY (S)
for (i in field_observations_to_files$tidalStage) { # tidalStage categories are stored here already
  name <- paste("spectra_S_", i, sep = "") # Used later for finding the table again
  assign(paste("spectra_S_", i, sep = ""), subset(calWater_norm, tidalStage==i)) # Make subset per tidal stage
  # Make empty rspec table to add to in next loop
  empty <- as.rspec(allspectra_att$Spectrum[372][[1]]) # Just a random wavelength-intensity table
  empty$intensity = 0 # Make intenisty zero, template to add to later
  rspec_build <- empty
  
  for (j in 1:nrow(get(name))) { # Loop through all rows of one subset
    select1 <- get(name)$Spectrum[j][[1]] # Get calWater spectrum, including normalized and calSky copy columns
    select2 <- select1[,-3] # Delete normalized column (in this case)
    select3 <- select2[,-2] # Delete intensity (calWater) column (in this case)
    rspec_i <- as.rspec(select3) # Find spectrum for this [i]
    assign(paste("rspec_S_", i, sep = ""), merge(rspec_build, rspec_i)) # Add new one to the old version from previous row
    rspec_build <- get(paste("rspec_S_", i, sep = "")) # Overwrite the old version for the next loop [i]
  }
  # Remove the 0 column needed for initializing
  temp_spec <- get(paste("rspec_S_", i, sep = ""))[,-2]
  assign(paste("rspec_S_", i, sep = ""), temp_spec)
}

# 3.1.3 PER TIDAL STAGE, FOR NORMALIZED (N): calWater / calSky
for (i in field_observations_to_files$tidalStage) { # tidalStage categories are stored here already
  name <- paste("spectra_N_", i, sep = "") # Used later for finding the table again
  assign(paste("spectra_N_", i, sep = ""), subset(calWater_norm, tidalStage==i)) # Make subset per tidal stage
  # Make empty rspec table to add to in next loop
  empty <- as.rspec(allspectra_att$Spectrum[372][[1]]) # Just a random wavelength-intensity table
  empty$intensity = 0 # Make intenisty zero, template to add to later
  rspec_build <- empty
  
  for (j in 1:nrow(get(name))) { # Loop through all rows of one subset
    select1 <- get(name)$Spectrum[j][[1]] # Get calWater spectrum, including normalized and calSky copy columns
    select2 <- select1[,-4] # Delete calSky column (in this case)
    select3 <- select2[,-2] # Delete intensity (calWater) column (in this case)
    rspec_i <- as.rspec(select3) # Find spectrum for this [i]
    assign(paste("rspec_N_", i, sep = ""), merge(rspec_build, rspec_i)) # Add new one to the old version from previous row
    rspec_build <- get(paste("rspec_N_", i, sep = "")) # Overwrite the old version for the next loop [i]
  }
  # Remove the 0 column needed for initializing
  temp_spec <- get(paste("rspec_N_", i, sep = ""))[,-2]
  assign(paste("rspec_N_", i, sep = ""), temp_spec)
}

# ONLY RUN WHEN PLOTS ARE NEEDED
# 3.1.4 Plots with the rspec package

# Merge waters
assign("rspec_W_01", merge(rspec_W_0_Test, rspec_W_1_HW))
assign("rspec_W_02", merge(rspec_W_01, rspec_W_2_HW_HWxLW))
assign("rspec_W_03", merge(rspec_W_02, rspec_W_3_HWxLW))
assign("rspec_W_04", merge(rspec_W_03, rspec_W_4_HWxLW_LW))
assign("rspec_W_05", merge(rspec_W_04, rspec_W_5_LW))
assign("rspec_W_06", merge(rspec_W_05, rspec_W_6_LW_LWxHW))
assign("rspec_W_07", merge(rspec_W_06, rspec_W_7_LW_HW))
# Also merge for colours

# Merge skys
assign("rspec_S_01", merge(rspec_S_0_Test, rspec_S_1_HW))
assign("rspec_S_02", merge(rspec_S_01, rspec_S_2_HW_HWxLW))
assign("rspec_S_03", merge(rspec_S_02, rspec_S_3_HWxLW))
assign("rspec_S_04", merge(rspec_S_03, rspec_S_4_HWxLW_LW))
assign("rspec_S_05", merge(rspec_S_04, rspec_S_5_LW))
assign("rspec_S_06", merge(rspec_S_05, rspec_S_6_LW_LWxHW))
assign("rspec_S_07", merge(rspec_S_06, rspec_S_7_LW_HW))

# Merge normalized
assign("rspec_N_01", merge(rspec_N_0_Test, rspec_N_1_HW))
assign("rspec_N_02", merge(rspec_N_01, rspec_N_2_HW_HWxLW))
assign("rspec_N_03", merge(rspec_N_02, rspec_N_3_HWxLW))
assign("rspec_N_04", merge(rspec_N_03, rspec_N_4_HWxLW_LW))
assign("rspec_N_05", merge(rspec_N_04, rspec_N_5_LW))
assign("rspec_N_06", merge(rspec_N_05, rspec_N_6_LW_LWxHW))
assign("rspec_N_07", merge(rspec_N_06, rspec_N_7_LW_HW))

# WATER; CHECK WHICH COLORS ARE ASSIGNED
pdf(file="outputdata/spectra/water_sky_norm_notperstage.pdf", height = 6, width = 8)
par( mfrow= c(1,3) ) # Room for legend as well
plot(rspec_S_07, ylab = "Intensity mW/(m^2 nm)", main = "Spectrometer Sky", col=alpha("black", 0.5), ylim=c(-10,550))
plot(rspec_W_07, ylab = "Intensity mW/(m^2 nm)", main = "Spectrometer Water", col=alpha("black", 0.5), ylim=c(-10,550))
plot(rspec_N_07, ylab = "Intensity mW/(m^2 nm)", main = "Ratio Water/Sky", col=alpha("black", 0.5), ylim=c(-0.05,1))
dev.off()

# WATER; CHECK WHICH COLORS ARE ASSIGNED
pdf(file="outputdata/spectra/water_sky_norm_final.pdf", height = 30, width = 30)
par( mfrow= c(3,8) ) # Room for legend as well
# draw plots

# SKY
#pdf(file="outputdata/spectra/sky.pdf", height = 10, width = 30)
# par( mfrow= c(1,7) ) # Room for legend as well
# draw plots
plot(rspec_S_0_Test, ylab = "Intensity mW/(m^2 nm)", main = "Stage 0_Test (S)", col=spectra_N_0_Test$color, ylim=c(-10,550))
plot(rspec_S_1_HW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 1_HW (S)", col=spectra_N_1_HW$color, ylim=c(-10,550))
plot(rspec_S_2_HW_HWxLW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 2_HW_HWxLW (S)", col=spectra_N_2_HW_HWxLW$color, ylim=c(-10,550)) #
plot(rspec_S_3_HWxLW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 3_HWxLW (S)", col=spectra_N_3_HWxLW$color, ylim=c(-10,550)) #
plot(rspec_S_4_HWxLW_LW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 4_HWxLW_LW (S)", col=spectra_N_4_HWxLW_LW$color, ylim=c(-10,550)) #
plot(rspec_S_5_LW, ylab = "Intensity mW/(m^2 nm)", main = "5_LW (S)", col=spectra_N_5_LW$color, ylim=c(-10,550)) #
plot(rspec_S_6_LW_LWxHW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 6 LW_LWxHW (S)", col=spectra_N_6_LW_LWxHW$color, ylim=c(-10,550)) #
plot(rspec_S_7_LW_HW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 7 LW_HW (S)", col=spectra_N_7_LW_HW$color, ylim=c(-10,550)) ##
#dev.off()

plot(rspec_W_0_Test, ylab = "Intensity mW/(m^2 nm)", main = "Stage 0_Test (W)", col=spectra_N_0_Test$color, ylim=c(-10,550))
plot(rspec_W_1_HW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 1_HW (W)", col=spectra_N_1_HW$color, ylim=c(-10,550))
plot(rspec_W_2_HW_HWxLW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 2_HW_HWxLW (W)", col=spectra_N_2_HW_HWxLW$color, ylim=c(-10,550)) #
plot(rspec_W_3_HWxLW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 3_HWxLW (W)", col=spectra_N_3_HWxLW$color, ylim=c(-10,550)) #
plot(rspec_W_4_HWxLW_LW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 4_HWxLW_LW (W)", col=spectra_N_4_HWxLW_LW$color, ylim=c(-10,550)) #
plot(rspec_W_5_LW, ylab = "Intensity mW/(m^2 nm)", main = "5_LW (W)", col=spectra_N_5_LW$color, ylim=c(-10,550)) #
plot(rspec_W_6_LW_LWxHW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 6 LW_LWxHW (W)", col=spectra_N_6_LW_LWxHW$color, ylim=c(-10,550)) #
plot(rspec_W_7_LW_HW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 7 LW_HW (W)", col=spectra_N_7_LW_HW$color, ylim=c(-10,550)) ##

# NORMALIZED
#pdf(file="outputdata/spectra/normalized.pdf", height = 10, width = 30)
#par( mfrow= c(1,7) ) # Room for legend as well
# draw plots
plot(rspec_N_0_Test, ylab = "Intensity mW/(m^2 nm)", main = "Stage 0_Test (N)", col=spectra_N_0_Test$color, ylim=c(-0.05,1))
plot(rspec_N_1_HW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 1_HW (N)", col=spectra_N_1_HW$color, ylim=c(-0.05,1))
plot(rspec_N_2_HW_HWxLW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 2_HW_HWxLW (N)", col=spectra_N_2_HW_HWxLW$color, ylim=c(-0.05,1)) #
plot(rspec_N_3_HWxLW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 3_HWxLW (N)", col=spectra_N_3_HWxLW$color, ylim=c(-0.05,1)) #
plot(rspec_N_4_HWxLW_LW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 4_HWxLW_LW (N)", col=spectra_N_4_HWxLW_LW$color, ylim=c(-0.05,1)) #
plot(rspec_N_5_LW, ylab = "Intensity mW/(m^2 nm)", main = "5_LW (N)", col=spectra_N_5_LW$color, ylim=c(-0.05,1)) #
plot(rspec_N_6_LW_LWxHW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 6 LW_LWxHW (N)", col=spectra_N_6_LW_LWxHW$color, ylim=c(-0.05,1)) #
plot(rspec_N_7_LW_HW, ylab = "Intensity mW/(m^2 nm)", main = "Stage 7 LW_HW (N)", col=spectra_N_7_LW_HW$color, ylim=c(-0.05,1)) ##
dev.off()

### 3.1.5  Important files thus far
calWater_norm # Contains all metadata and spectra, one row per .dat file, spectra nested; not corrected for <0 intensity values
spectra_megabase # Contains to be used spectra; and to be used metadata; but not not nested but all below each other; corrected for <0 intensity values

# SHOWS CALIBRATION OF COUNTS FROM WATER IS NOT SO WELL <
spectra_megabase_below0inwater <- filter(spectra_megabase, intensity <= 0)
plot(spectra_megabase_below0inwater$wavelength, spectra_megabase_below0inwater$intensity )
# Soo 400-700 is fine for integration

spectra_megabase_IR <- filter(spectra_megabase, wavelength >= 750)
plot(spectra_megabase_IR$wavelength, spectra_megabase_IR$intensity, ylim=c(-20,20))
spectra_megabase_IRbelow0 <- filter(spectra_megabase_IR, intensity <= 0)
plot(spectra_megabase_IRbelow0$wavelength, spectra_megabase_IRbelow0$intensity)
plot(spectra_megabase_IRbelow0$wavelength, spectra_megabase_IRbelow0$depth_approx_m) # At which depths usually < 0?
# Apparently from ~0.8m onwards no 750nm light anymore, from 850nm to 950nm from ~0.6m to 0 m quite exponentially
plot(spectra_megabase_IR$depth_approx_m, spectra_megabase_IR$intensity) #

# Remove wavelengths lower than 350 and larger than 900 nm due to noise in calibration file
spectra_megabase_cliprange_lowonly <- filter(spectra_megabase, wavelength >= 350)
spectra_megabase_clip <- filter(spectra_megabase_cliprange_lowonly, wavelength <= 900)

# Look for similar incoming spectra in different tidal stages (based on calSky)
spectra_megabase_clip_550 <- filter(spectra_megabase_clip, wavelength == 550)

# Similarities in calSky for same depth but different tidal stage:
choose_2 <- filter(spectra_megabase, IDNumber == 2) 
choose_371 <- filter(spectra_megabase, IDNumber == 371)
sum(choose_2$copy_calSky) # 0_Test 0.183m ; sum calWater = 2056.113 ; sum calSky = 5237.612
sum(choose_371$copy_calSky) # 7_LW_HW 0.211m ; sum calWater = 2345.359 ; sum calSky = 5712.13

# LW/HW difference
choose_59 <- filter(spectra_megabase, IDNumber == 59) 
choose_263 <- filter(spectra_megabase, IDNumber == 263)
choose_59$depth_approx_m # HW 1.466 ; sum calWater = 15533.86 ; sum calSky = 113868.9
choose_263$depth_approx_m # LW 1.575m ; sum calWater = 7834.416 ; sum calSky = 114164
plot(choose_263$wavelength, choose_263$copy_calSky, col="red")
points(choose_59$wavelength, choose_59$intensity, col="orange")
points(choose_263$wavelength, choose_263$intensity, col="red")
points(choose_59$wavelength, choose_59$copy_calSky, col="orange")

### Section 4: With spectra_megabase, calculate nice things
# Subselections based on diepte
# Visualize how deep all measurements have been made
plot(-calWater_norm$depth_approx_m)
abline(h=seq(0, -3.2, by = -0.2)) # Check where measurements where made
min(spectra_megabase$depth_approx_m) # -0.109
max(spectra_megabase$depth_approx_m) # 3.202

################# STATS FOR PLOTTING OVER TIME

maxperobs <- tibble(
  lambda = c(1),
  max.I = c(1),
  ratio.max.I = c(1),
  DateTimeUTC = c("1"),
  depth = c(1),
  IDNumber = c(1),
  tidalStage = c("1")
)

# Find max. values per observation
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_megabase, IDNumber == i)
  max_intensity <- max(subsettemp_df$intensity)
  max.I <- max(subsettemp_df$intensity)
  lambda <- subsettemp_df$wavelength[[which(subsettemp_df$intensity == max_intensity)]]
  ratio.max.I<- subsettemp_df$intensity_normalized[[which(subsettemp_df$intensity == max_intensity)]]
  DateTimeUTC <- subsettemp_df$DateTime_UTC[[which(subsettemp_df$intensity == max_intensity)]]
  depth <- subsettemp_df$depth_approx_m[[which(subsettemp_df$intensity == max_intensity)]]
  tidalStage <- subsettemp_df$tidalStage[[which(subsettemp_df$intensity == max_intensity)]]
  IDNumber <- i
  
  maxperobs <- add_row(maxperobs, lambda=lambda, max.I=max.I, ratio.max.I=ratio.max.I,
          DateTimeUTC=DateTimeUTC, depth=depth, IDNumber=IDNumber, tidalStage=tidalStage)
}

maxperobs <- maxperobs[-1,]

# Convert DateTime
maxperobs$DateTime_CEST <- as.POSIXct(maxperobs$DateTimeUTC, tz = "Europe/Paris") + hours(2)

# Find integrated value for GREEEEEEEEEEEN (500-600 nm)
spectra_greentemp <- filter(spectra_megabase, wavelength >= 500)
spectra_green <- filter(spectra_greentemp, wavelength < 600)

# Non-normalized
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_green, IDNumber == i)
  integ_green <- sum(subsettemp_df$intensity)
  integ_green_mean <- integ_green/100 # Divided by 100 nm (490-590 range)
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$int.green[indexnr] <- integ_green
  maxperobs$integ_green_mean[indexnr] <- integ_green_mean
}

# Non-normalized SKY
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_green, IDNumber == i)
  integ_green <- sum(subsettemp_df$copy_calSky)
  integ_green_mean <- integ_green/100 # Divided by 100 nm (490-590 range)
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$int.green.sky[indexnr] <- integ_green
  maxperobs$integ_green_mean.sky[indexnr] <- integ_green_mean
}

# Normalized
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_green, IDNumber == i)
  integ_green_norm <- sum(subsettemp_df$intensity_normalized)
  integ_green_norm_mean <- integ_green_norm/100
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$integ_green_norm[indexnr] <- integ_green_norm
  maxperobs$ratio.green[indexnr] <- integ_green_norm_mean
}

# Find integrated value for BLUEEEEEEEE (400-500 nm)
spectra_bluetemp <- filter(spectra_megabase, wavelength >= 400)
spectra_blue <- filter(spectra_bluetemp, wavelength < 500)

# Non-normalized blue
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_blue, IDNumber == i)
  integ_blue <- sum(subsettemp_df$intensity)
  integ_blue_mean <- integ_blue/100 # Divided by 100 nm (490-590 range)
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$int.blue[indexnr] <- integ_blue
  maxperobs$integ_blue_mean[indexnr] <- integ_blue_mean
}

# Non-normalized blue SKY
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_blue, IDNumber == i)
  integ_blue <- sum(subsettemp_df$copy_calSky)
  integ_blue_mean <- integ_blue/100 # Divided by 100 nm (490-590 range)
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$int.blue.sky[indexnr] <- integ_blue
  maxperobs$integ_blue_mean.sky[indexnr] <- integ_blue_mean
}

# Normalized blue
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_blue, IDNumber == i)
  integ_blue_norm <- sum(subsettemp_df$intensity_normalized)
  integ_blue_norm_mean <- integ_blue_norm/100
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$integ_blue_norm[indexnr] <- integ_blue_norm
  maxperobs$ratio.blue[indexnr] <- integ_blue_norm_mean
}

# Find integrated value for RED 600-700 nm)
spectra_redtemp <- filter(spectra_megabase, wavelength >= 600)
spectra_red <- filter(spectra_redtemp, wavelength < 700)

# Non-normalized red
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_red, IDNumber == i)
  integ_red <- sum(subsettemp_df$intensity)
  integ_red_mean <- integ_red/100 # Divided by 100 nm
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$int.red[indexnr] <- integ_red
  maxperobs$integ_red_mean[indexnr] <- integ_red_mean
}

# Non-normalized red SKY
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_red, IDNumber == i)
  integ_red <- sum(subsettemp_df$copy_calSky)
  integ_red_mean <- integ_red/100 # Divided by 100 nm
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$int.red.sky[indexnr] <- integ_red
  maxperobs$integ_red_mean.sky[indexnr] <- integ_red_mean
}

# Normalized red
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_red, IDNumber == i)
  integ_red_norm <- sum(subsettemp_df$intensity_normalized)
  integ_red_norm_mean <- integ_red_norm/100
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$integ_red_norm[indexnr] <- integ_red_norm
  maxperobs$ratio.red[indexnr] <- integ_red_norm_mean
}

# Find integrated value for red/IR (700-800)
# Quite some intensities < 0 so might result in weird results!
spectra_IRtemp <- filter(spectra_megabase, wavelength >= 700)
spectra_IR <- filter(spectra_IRtemp, wavelength < 800)

# Non-normalized IR
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_IR, IDNumber == i)
  integ_IR <- sum(subsettemp_df$intensity)
  integ_IR_mean <- integ_IR/100 # Divided by 100 nm (490-590 range)
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$int.IR[indexnr] <- integ_IR
  maxperobs$integ_IR_mean[indexnr] <- integ_IR_mean
}

# Non-normalized IR SKY
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_IR, IDNumber == i)
  integ_IR <- sum(subsettemp_df$copy_calSky)
  integ_IR_mean <- integ_IR/100 # Divided by 100 nm (490-590 range)
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$int.IR.sky[indexnr] <- integ_IR
  maxperobs$integ_IR_mean.sky[indexnr] <- integ_IR_mean
}

# Normalized IR DO NOT USE THIS ONE, too many weird numbers
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_IR, IDNumber == i)
  integ_IR_norm <- sum(subsettemp_df$intensity_normalized)
  integ_IR_norm_mean <- integ_IR_norm/100
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$integ_IR_norm[indexnr] <- integ_IR_norm
  maxperobs$ratio.IR[indexnr] <- integ_IR_norm_mean
}

# Find integrated value for "whole spectrum" (400-700 ivm bad calibration at outer ends)
spectra_inttemp <- filter(spectra_megabase, wavelength >= 400)
spectra_whole <- filter(spectra_inttemp, wavelength < 700)

# Non-normalized whole
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_whole, IDNumber == i)
  integ_whole <- sum(subsettemp_df$intensity)
  integ_whole_mean <- integ_whole/300 # Divided by 100 nm (490-590 range)
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$int.full[indexnr] <- integ_whole
  maxperobs$integ_whole_mean[indexnr] <- integ_whole_mean
}

# ADD calSKY INT (later toegevoegd, verwijderen bij error)
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_whole, IDNumber == i)
  integ_sky <- sum(subsettemp_df$copy_calSky)
  integ_sky_mean <- integ_sky/300 # Divided by 100 nm (490-590 range)
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$int.sky[indexnr] <- integ_sky
  maxperobs$integ_sky_mean[indexnr] <- integ_sky_mean
}

# Normalized whole
for (i in unique(spectra_megabase$IDNumber)) {
  subsettemp_df <- subset(spectra_whole, IDNumber == i)
  integ_whole_norm <- sum(subsettemp_df$intensity_normalized)
  integ_whole_norm_mean <- integ_whole_norm/300
  indexnr <- which(maxperobs$IDNumber == i)
  maxperobs$integ_whole_norm[indexnr] <- integ_whole_norm
  maxperobs$ratio.full[indexnr] <- integ_whole_norm_mean
}

# Normalized whole, but now from the intWater and intSky
maxperobs$int.ratio.full.2nd <- maxperobs$int.full / maxperobs$int.sky

plot(maxperobs$ratio.full, maxperobs$int.ratio.full.2nd)
maxperobs$difference.ratio.full <- maxperobs$ratio.full - maxperobs$int.ratio.full.2nd
max(maxperobs$difference.ratio.full) # 0.004196781 , so minimal difference on the 0-1 scale (max. 0.01) 

### Section 4: Waterheight data
### 1.3 Load waterheight data NIOZ
rawdata <- read_csv("inputdata/waterheight/hr_wht202210.csv")
# datetime in UTC, waterheight NAP in cm

# Convert time to local time (and waterheight data is in cm NAP)
data_CEST <- as_tibble(rawdata) %>% rename(DateTime_CEST = datetime)
data_CEST$DateTime_CEST <- as.POSIXct(rawdata$datetime, tz = "Europe/Paris") + hours(2)

# Remove some data that is not needed
oneday <- filter(data_CEST, DateTime_CEST > as.POSIXct("2022-10-26 07:29:59", tz="Europe/Paris")) %>% filter(DateTime_CEST < as.POSIXct("2022-10-26 23:30:00", tz="Europe/Paris"))

# Smooth data per minute to remove effect of waves
oneday_incl <-  mutate(oneday, hour = hour(DateTime_CEST))
oneday_incl <-  mutate(oneday_incl, minute = minute(DateTime_CEST))
oneday_incl <-  mutate(oneday_incl, second = second(DateTime_CEST))
oneday_incl$TimeIDNumber <- oneday_incl$hour*100 + oneday_incl$minute

# Prepare for storage
oneday_perminute <- filter(oneday_incl, second == 0)
oneday_perminute$nap_in_cm <- NA # Empty

# For temporary storage
temp_mean <- tibble(
  TimeIDNumber = numeric(),
  nap_in_cm = numeric()
)

for (i in 1:nrow(oneday_incl)) {
  find_ID <- oneday_incl$TimeIDNumber[i]
  selection_df <- oneday_incl[oneday_incl$TimeIDNumber == find_ID, ]
  wh <- mean(selection_df$nap_in_cm)
  
  
  temp_mean <- add_row(temp_mean, TimeIDNumber = find_ID, nap_in_cm = wh)
}
# Remove duplicates
temp_mean_clean <- temp_mean[!duplicated(temp_mean$TimeIDNumber),]

# Link the means to the original table (temp_mean_clean to oneday_perminute)
oneday_perminute$nap_in_cm <- temp_mean_clean$nap_in_cm
# Only what we want to plot
waterheight_smoothed <- tibble(DateTime_CEST = oneday_perminute$DateTime_CEST, nap_in_cm = oneday_perminute$nap_in_cm, disttoseab_cm = oneday_perminute$nap_in_cm+300)

# Timespan of measurements
timebar <- tibble(DateTime_CEST = as.POSIXct(calWater_norm$DateTime_UTC, tz = "Europe/Paris") + hours(2), value = 0) # Temp value 0
# At these times, how high were the samples? Distance to seabed = 0 = -3,0m NAP

# Color per sample
colfunc7 <- colorRampPalette(c("#f3e79b","#fac484","#f8a07e","#eb7f86","#ce6693","#a059a0","#5c53a5", "#00008B"))
colfunc3 <- colorRampPalette(c("#f3e79b","#fac484","#f8a07e","#eb7f86","#ce6693","#a059a0","#5c53a5"))
colfunc4 <- colorRampPalette(c("#00008B","#c6E2FF"))#00008B
#f3e79b,#fac484,#f8a07e,#eb7f86,#ce6693,#a059a0,#5c53a5

timespan <- tibble(
  samplenr = c(1:21),
  distoseabed_m = c(0.2, 0.4, 0.6, 0.8, 1.0, 1.2, 1.4, 1.6, 1.8, 2.0, 2.2, 2.4, 2.6, 2.8, 3.0, 3.4, 3.8, 4.2, 5.0, 5.4, 0.1),
  color = colfunc4(21)
)

timespan$nap_in_cm <- (timespan$distoseabed_m - 3)*100 -10 # -10 correction for correction afterwards based on field observations
timespan$distoseabed_cm <- timespan$distoseabed_m*100
#timespan$t0_1 <- as.POSIXct("2022-10-26 06:34:00", tz = "Europe/Paris")+ hours(2)
#timespan$t0_2 <- as.POSIXct("2022-10-26 06:50:00", tz = "Europe/Paris")+ hours(2)
timespan$t0_CEST <- as.POSIXct("2022-10-26 06:42:00", tz = "Europe/Paris")+ hours(2)
timespan$t0_wh_nap_in_cm <- waterheight_smoothed$nap_in_cm[[which(waterheight_smoothed$DateTime_CEST == timespan$t0_CEST[1])]]
#timespan$t1_1 <- as.POSIXct("2022-10-26 07:48:00", tz = "Europe/Paris")+ hours(2)
#timespan$t1_2 <- as.POSIXct("2022-10-26 08:15:00", tz = "Europe/Paris")+ hours(2)
timespan$t1_CEST <- as.POSIXct("2022-10-26 08:02:00", tz = "Europe/Paris")+ hours(2)
timespan$t1_wh_nap_in_cm <- waterheight_smoothed$nap_in_cm[[which(waterheight_smoothed$DateTime_CEST == timespan$t1_CEST[1])]]
#timespan$t2_1 <- as.POSIXct("2022-10-26 09:27:00", tz = "Europe/Paris")+ hours(2)
#timespan$t2_2 <- as.POSIXct("2022-10-26 09:41:00", tz = "Europe/Paris")+ hours(2)
timespan$t2_CEST <- as.POSIXct("2022-10-26 09:34:00", tz = "Europe/Paris")+ hours(2)
timespan$t2_wh_nap_in_cm <- waterheight_smoothed$nap_in_cm[[which(waterheight_smoothed$DateTime_CEST == timespan$t2_CEST[1])]]
#timespan$t3_1 <- as.POSIXct("2022-10-26 10:53:00", tz = "Europe/Paris")+ hours(2)
#timespan$t3_2 <- as.POSIXct("2022-10-26 11:04:00", tz = "Europe/Paris")+ hours(2)
timespan$t3_CEST <- as.POSIXct("2022-10-26 10:59:00", tz = "Europe/Paris")+ hours(2)
timespan$t3_wh_nap_in_cm <- waterheight_smoothed$nap_in_cm[[which(waterheight_smoothed$DateTime_CEST == timespan$t3_CEST[1])]]
#timespan$t4_1 <- as.POSIXct("2022-10-26 12:29:00", tz = "Europe/Paris")+ hours(2)
#timespan$t4_2 <- as.POSIXct("2022-10-26 12:41:00", tz = "Europe/Paris")+ hours(2)
timespan$t4_CEST <- as.POSIXct("2022-10-26 12:35:00", tz = "Europe/Paris")+ hours(2)
timespan$t4_wh_nap_in_cm <- waterheight_smoothed$nap_in_cm[[which(waterheight_smoothed$DateTime_CEST == timespan$t4_CEST[1])]]
#timespan$t5_1 <- as.POSIXct("2022-10-26 13:57:00", tz = "Europe/Paris")+ hours(2)
#timespan$t5_2 <- as.POSIXct("2022-10-26 14:09:00", tz = "Europe/Paris")+ hours(2)
timespan$t5_CEST <- as.POSIXct("2022-10-26 14:03:00", tz = "Europe/Paris")+ hours(2)
timespan$t5_wh_nap_in_cm <- waterheight_smoothed$nap_in_cm[[which(waterheight_smoothed$DateTime_CEST == timespan$t5_CEST[1])]]
#timespan$t6_1 <- as.POSIXct("2022-10-26 14:55:00", tz = "Europe/Paris")+ hours(2)
#timespan$t6_2 <- as.POSIXct("2022-10-26 15:11:00", tz = "Europe/Paris")+ hours(2)
timespan$t6_CEST <- as.POSIXct("2022-10-26 15:03:00", tz = "Europe/Paris")+ hours(2)
timespan$t6_wh_nap_in_cm <- waterheight_smoothed$nap_in_cm[[which(waterheight_smoothed$DateTime_CEST == timespan$t6_CEST[1])]]
#timespan$t7_1 <- as.POSIXct("2022-10-26 15:59:00", tz = "Europe/Paris")+ hours(2)
#timespan$t7_2 <- as.POSIXct("2022-10-26 16:12:00", tz = "Europe/Paris")+ hours(2)
timespan$t7_CEST <- as.POSIXct("2022-10-26 16:06:00", tz = "Europe/Paris")+ hours(2)
timespan$t7_wh_nap_in_cm <- waterheight_smoothed$nap_in_cm[[which(waterheight_smoothed$DateTime_CEST == timespan$t7_CEST[1])]]


for (i in 1:nrow(timespan)) {
  timespan$t0_depth_cm[i] <- timespan$t0_wh_nap_in_cm[i] - timespan$nap_in_cm[i]
  timespan$t1_depth_cm[i] <- timespan$t1_wh_nap_in_cm[i] - timespan$nap_in_cm[i]
  timespan$t2_depth_cm[i] <- timespan$t2_wh_nap_in_cm[i] - timespan$nap_in_cm[i]
  timespan$t3_depth_cm[i] <- timespan$t3_wh_nap_in_cm[i] - timespan$nap_in_cm[i]
  timespan$t4_depth_cm[i] <- timespan$t4_wh_nap_in_cm[i] - timespan$nap_in_cm[i]
  timespan$t5_depth_cm[i] <- timespan$t5_wh_nap_in_cm[i] - timespan$nap_in_cm[i]
  timespan$t6_depth_cm[i] <- timespan$t6_wh_nap_in_cm[i] - timespan$nap_in_cm[i]
  timespan$t7_depth_cm[i] <- timespan$t7_wh_nap_in_cm[i] - timespan$nap_in_cm[i]
  timespan$samplenr2[i] <- timespan$samplenr[i]
}

for (i in 1:nrow(timespan)) {
  depth_sample_over_time <- waterheight_smoothed$nap_in_cm - timespan$nap_in_cm[i]
  waterheight_smoothed <- add_column(waterheight_smoothed, depth_sample_over_time)
  colnames(waterheight_smoothed)[i+3] = paste("depth_sample_", i, sep = "")
  #name <- paste("sample_", i, sep = "")
  #rename(paste("sample_", i, sep = "") = depth_sample_over_time)
}

# Add waterheight in NAP to maxperobs database
# Smooth data per minute to remove effect of waves
spectrumstatsnap <-  mutate(maxperobs, hour = hour(DateTime_CEST))
spectrumstatsnap <-  mutate(spectrumstatsnap, minute = minute(DateTime_CEST))
spectrumstatsnap <-  mutate(spectrumstatsnap, second = second(DateTime_CEST))
spectrumstatsnap$TimeIDNumber <- spectrumstatsnap$hour*100 + spectrumstatsnap$minute

for (i in 1:nrow(spectrumstatsnap)) {
  timestamp <- spectrumstatsnap$TimeIDNumber[i]
  # Localize time in 'oneday_incl' database, find waterlevel at that time
  napvalue <- temp_mean_clean$nap_in_cm[[which(temp_mean_clean$TimeIDNumber == timestamp)]]
  # Now we have the waterlevel, so convert depth to NAP with this waterlevel
  spectrumstatsnap$nap_in_cm[i] <- napvalue - spectrumstatsnap$depth[i]*100
}

library(plyr)
spectrumstatsnap$nap_in_cm_round <- round_any(spectrumstatsnap$nap_in_cm, 10)

# GROUPPED PLOT NAP
integrationplot <- ggplot(data=spectrumstatsnap, aes(x=int.full, y=nap_in_cm, group=tidalStage))
integrationplot <- integrationplot + geom_point(aes(shape=tidalStage, color=tidalStage, size=tidalStage, fill=tidalStage)) + scale_size_manual(values=c(4,4,4,4,4,4,4,4)) + scale_shape_manual(values=c(21,21,21,21,21,21,21,21)) + scale_color_manual(values=c('#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F', '#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F')) #+ scale_fill_manual(values=c( "#FFFFE5", "#FEE391", "#FB9A29", "#CC4C02"))
integrationplot <- integrationplot + theme_bw()
print(integrationplot)
# CALC MEAN PER INCOMING CALSKY
manipulate <- spectrumstatsnap
meanperstage_int.sky <- aggregate(manipulate$int.sky, list(manipulate$tidalStage), FUN=mean)
for (i in 1:nrow(manipulate)) {
  stage <- manipulate$tidalStage[i]
  int.sky <- meanperstage_int.sky$x[which(meanperstage_int.sky$Group.1==stage)]
  manipulate$int.full[i] <- int.sky
  # manipulate$tidalStage[i] <- "Sky" Deze pas als ook alle signals zijn gedaan
}

meanperstage_int.blue.sky <- aggregate(manipulate$int.blue.sky, list(manipulate$tidalStage), FUN=mean)
for (i in 1:nrow(manipulate)) {
  stage <- manipulate$tidalStage[i]
  int.blue.sky <- meanperstage_int.blue.sky$x[which(meanperstage_int.blue.sky$Group.1==stage)]
  manipulate$int.blue[i] <- int.blue.sky
  # manipulate$tidalStage[i] <- "Sky" Deze pas als ook alle signals zijn gedaan
}

meanperstage_int.green.sky <- aggregate(manipulate$int.green.sky, list(manipulate$tidalStage), FUN=mean)
for (i in 1:nrow(manipulate)) {
  stage <- manipulate$tidalStage[i]
  int.green.sky <- meanperstage_int.green.sky$x[which(meanperstage_int.green.sky$Group.1==stage)]
  manipulate$int.green[i] <- int.green.sky
  # manipulate$tidalStage[i] <- "Sky" Deze pas als ook alle signals zijn gedaan
}

meanperstage_int.red.sky <- aggregate(manipulate$int.red.sky, list(manipulate$tidalStage), FUN=mean)
for (i in 1:nrow(manipulate)) {
  stage <- manipulate$tidalStage[i]
  int.red.sky <- meanperstage_int.red.sky$x[which(meanperstage_int.red.sky$Group.1==stage)]
  manipulate$int.red[i] <- int.red.sky
  # manipulate$tidalStage[i] <- "Sky" Deze pas als ook alle signals zijn gedaan
}

meanperstage_int.IR.sky <- aggregate(manipulate$int.IR.sky, list(manipulate$tidalStage), FUN=mean)
for (i in 1:nrow(manipulate)) {
  stage <- manipulate$tidalStage[i]
  int.IR.sky <- meanperstage_int.IR.sky$x[which(meanperstage_int.IR.sky$Group.1==stage)]
  manipulate$int.IR[i] <- int.IR.sky
  # manipulate$tidalStage[i] <- "Sky" Deze pas als ook alle signals zijn gedaan
}

# Overwrite where it's coming from
manipulate$tidalStage <- "Sky"
spectrumstatsnap_withcalSky <- spectrumstatsnap
spectrumstatsnap_withcalSky <- as.data.frame(spectrumstatsnap)
manipulate <- as.data.frame(manipulate)

# Select rows to keep (multiple in case of deeper stuff)
# Just select one or multiple that's kind of in the middle qua time
# 0
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[16, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 130
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[16, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 110
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[16, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 90
# 1
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[63, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 130
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[63, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 110

# 2
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[119, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 130
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[119, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 110
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[119, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 90
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[119, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 70

# 3
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[156, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 130
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[156, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 110
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[156, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 90
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[156, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 70
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[156, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 50
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[156, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 30
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[156, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 10

# 4
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[202, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 130
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[202, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 110
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[202, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 90
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[202, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 70
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[202, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 50
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[202, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 30
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[202, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 10
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[202, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- -10
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[202, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- -30

# 5
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[235, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 130
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[235, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 110
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[235, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 90
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[235, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 70
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[235, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 50
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[235, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 30
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[235, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 10
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[235, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- -10
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[235, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- -30
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[235, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- -50

# 6
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[270, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 130
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[270, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 110
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[270, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 90
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[270, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 70
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[270, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 50
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[270, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 30

# 7
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[318, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 130
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[318, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 110
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[318, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 90
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[318, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 70
spectrumstatsnap_withcalSky[nrow(spectrumstatsnap_withcalSky)+1, ] <- manipulate[318, ]
spectrumstatsnap_withcalSky$nap_in_cm[nrow(spectrumstatsnap_withcalSky)] <- 50

spectrumstatsnap_withcalSky_copy <- spectrumstatsnap_withcalSky

# GROUPPED PLOT DEPTH 
integrationplot <- ggplot(data=spectrumstatsnap, aes(x=int.full, y=depth, group=tidalStage))
integrationplot <- integrationplot + geom_point(aes(shape=tidalStage, color=tidalStage, size=tidalStage, fill=tidalStage)) + scale_size_manual(values=c(4,4,4,4,4,4,4,4)) + scale_shape_manual(values=c(21,21,21,21,21,21,21,21)) + scale_color_manual(values=c('#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F', '#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F')) #+ scale_fill_manual(values=c( "#FFFFE5", "#FEE391", "#FB9A29", "#CC4C02"))
integrationplot <- integrationplot + theme_bw() + scale_y_reverse()
print(integrationplot)

# lm for all points throughout the day
ratio.full <- spectrumstatsnap$ratio.full
depth <- spectrumstatsnap$depth
linemodel <- lm(formula = log(ratio.full) ~ depth)
summary(linemodel) 

ratio.blue <- spectrumstatsnap$ratio.blue
depth <- spectrumstatsnap$depth
linemodel <- lm(formula = log(ratio.blue) ~ depth)
summary(linemodel)

ratio.green <- spectrumstatsnap$ratio.green
depth <- spectrumstatsnap$depth
linemodel <- lm(formula = log(ratio.green) ~ depth)
summary(linemodel)

ratio.red <- spectrumstatsnap$ratio.red
depth <- spectrumstatsnap$depth
linemodel <- lm(formula = log(ratio.red) ~ depth)
summary(linemodel)

ratio.IR <- spectrumstatsnap$ratio.IR
depth <- spectrumstatsnap$depth
linemodel <- lm(formula = log(ratio.IR) ~ depth)
summary(linemodel)

# GROUPPED PLOT DEPTH NORMALIZED (nice for attenuation question)
# Trend 0_Test
input0 <- filter(spectrumstatsnap, tidalStage == "0_Test")
ratio.full <- input0$ratio.full
depth <- input0$depth
line1model <- lm(formula = log(ratio.full) ~ depth)
summary(line1model) #0.9986
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df0 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df0 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df0$ratio_exp[[which(df0$depthvalues==3.640)]] # 0.04953057

# Trend 1_HW
input1 <- filter(spectrumstatsnap, tidalStage == "1_HW")
ratio.full <- input1$ratio.full
depth <- input1$depth
line1model <- lm(formula = log(ratio.full) ~ depth)
summary(line1model) #0.9564 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df1 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df1 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df1$ratio_exp[[which(df1$depthvalues==3.760)]] # 0.03506149

# Trend 2_HW_HWxLW
input2 <- filter(spectrumstatsnap, tidalStage == "2_HW_HWxLW")
ratio.full <- input2$ratio.full
depth <- input2$depth
line1model <- lm(formula = log(ratio.full) ~ depth)
summary(line1model) # 0.9892 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df2 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df2 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df2$ratio_exp[[which(df2$depthvalues==3.390)]] # 0.01342553


# Trend 3_HWxLW
input3 <- filter(spectrumstatsnap, tidalStage == "3_HWxLW")
ratio.full <- input3$ratio.full
depth <- input3$depth
line1model <- lm(formula = log(ratio.full) ~ depth)
summary(line1model) # 0.934 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df3 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df3 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df3$ratio_exp[[which(df3$depthvalues==2.805)]] # 0.07418709

# Trend 4_HWxLW_LW
input4 <- filter(spectrumstatsnap, tidalStage == "4_HWxLW_LW")
ratio.full <- input4$ratio.full
depth <- input4$depth
line1model <- lm(formula = log(ratio.full) ~ depth)
summary(line1model) # 0.9338
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df4 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df4 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df4$ratio_exp[[which(df4$depthvalues==2.370)]] # 0.05325477

# Trend 5_LW
input5 <- filter(spectrumstatsnap, tidalStage == "5_LW")
ratio.full <- input5$ratio.full
depth <- input5$depth
line1model <- lm(formula = log(ratio.full) ~ depth)
summary(line1model) # 0.9188
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df5 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df5 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df5$ratio_exp[[which(df5$depthvalues==2.120)]] # 0.03512075

# Trend 6_LW_LWxHW
input6 <- filter(spectrumstatsnap, tidalStage == "6_LW_LWxHW")
ratio.full <- input6$ratio.full
depth <- input6$depth
line1model <- lm(formula = log(ratio.full) ~ depth)
summary(line1model) # 0.9861
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df6 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df6 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df6$ratio_exp[[which(df6$depthvalues==2.970)]] # 0.04115593

# Trend 7_LW_HW
input7 <- filter(spectrumstatsnap, tidalStage == "7_LW_HW")
ratio.full <- input7$ratio.full
depth <- input7$depth
line1model <- lm(formula = log(ratio.full) ~ depth)
summary(line1model) # 0.9779
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df7 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df7 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df7$ratio_exp[[which(df7$depthvalues==3.340)]] # 0.02783322

colormap <- myPalette(8)
integrationplot <- ggplot(data=spectrumstatsnap, aes(x=ratio.full, y=depth, group=tidalStage))
integrationplot <- integrationplot + geom_line(inherit.aes=F, data=df0, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[1], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df1, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[2], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df2, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[3], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df3, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[4], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df4, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[5], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df5, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[6], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df6, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[7], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df7, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[8], size=2, alpha=0.5)
#integrationplot <- integrationplot + geom_point(inherit.aes=F, data=df0, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_point(inherit.aes=F, data=df1, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_point(inherit.aes=F, data=df2, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_point(inherit.aes=F, data=df3, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_point(inherit.aes=F, data=df4, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_point(inherit.aes=F, data=df5, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_point(inherit.aes=F, data=df6, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_point(inherit.aes=F, data=df7, mapping=aes(x=ratio_exp, y=depthvalues))
integrationplot <- integrationplot + geom_point(aes(shape=tidalStage, color=tidalStage, size=tidalStage, fill=tidalStage)) + scale_size_manual(values=c(2,2,2,2,2,2,2,2)) + scale_shape_manual(values=c(21,21,21,21,21,21,21,21)) + scale_color_manual(values=c('#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F', '#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F')) + scale_fill_manual(values=colormap)
integrationplot <- integrationplot + theme_bw() + labs(title = "Attenuation of the subaerial spectrum throughout the water column, per tidal stage") + theme(plot.title = element_text(size = 12, face = "bold", color = "black", hjust = 0.5))#+ scale_y_reverse()
#integrationplot <- integrationplot + geom_line(inherit.aes=F, data=df0, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[1], size=2) + geom_line(inherit.aes=F, data=df1, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[2]) + geom_line(inherit.aes=F, data=df2, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_line(inherit.aes=F, data=df3, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_line(inherit.aes=F, data=df4, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_line(inherit.aes=F, data=df5, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_line(inherit.aes=F, data=df6, mapping=aes(x=ratio_exp, y=depthvalues)) + geom_line(inherit.aes=F, data=df7, mapping=aes(x=ratio_exp, y=depthvalues))
integrationplot <- integrationplot + scale_y_continuous(name="Depth spectrometer (m)") + scale_y_reverse(name="Depth spectrometer (m)") + scale_x_continuous(name="Ratio (Water/Sky, both integrated intensity over 400-700nm)", limits=c(0, 1), breaks=seq(min(0), max(1), by = 0.1))

print(integrationplot) # /outputdata/spectra/final_plots/Attenuation_Depth_Ratio_TidalStage 8x5 is nice

# Maybe also nice for the different colors?
# GROUPPED PLOT DEPTH NORMALIZED (nice for attenuation question)
integrationplot <- ggplot(data=spectrumstatsnap, aes(x=depth, y=ratio.full, group=tidalStage))
integrationplot <- integrationplot + geom_point(aes(shape=tidalStage, color=tidalStage, size=tidalStage, fill=tidalStage)) + scale_size_manual(values=c(3,3,3,3,3,3,3,3)) + scale_shape_manual(values=c(21,21,21,21,21,21,21,21)) + scale_color_manual(values=c('#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F', '#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F')) #+ scale_fill_manual(values=c( "#FFFFE5", "#FEE391", "#FB9A29", "#CC4C02"))
integrationplot <- integrationplot + theme_bw() + labs(title = "Attenuation of the subaerial spectrum throughout the water column, per tidal stage") + theme(plot.title = element_text(size = 12, face = "bold", color = "black", hjust = 0.5))#+ scale_y_reverse()
integrationplot <- integrationplot + scale_x_continuous(name="Depth spectrometer (m)") + scale_y_continuous(name="Ratio (Water/Sky 400-700nm)", limits=c(0, 1), breaks=seq(min(0), max(1), by = 0.1))
print(integrationplot)

# Rounded to 10cm nap plot
integrationplot <- ggplot(data=spectrumstatsnap, aes(x=int.full, y=nap_in_cm_round, group=tidalStage))
integrationplot <- integrationplot + geom_point(aes(shape=tidalStage, color=tidalStage, size=tidalStage, fill=tidalStage)) + scale_size_manual(values=c(4,4,4,4,4,4,4,4)) + scale_shape_manual(values=c(21,21,21,21,21,21,21,21)) + scale_color_manual(values=c('#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F', '#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F')) #+ scale_fill_manual(values=c( "#FFFFE5", "#FEE391", "#FB9A29", "#CC4C02"))
integrationplot <- integrationplot + theme_bw()
print(integrationplot)

# GROUPPED PLOT DEPTH NORMALIZED (nice for attenuation question) FOR BLUE LIGHT
# Trend 0_Test
input0 <- filter(spectrumstatsnap, tidalStage == "0_Test")
ratio.blue <- input0$ratio.blue
depth <- input0$depth
line1model <- lm(formula = log(ratio.blue) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df0 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 1_HW
input1 <- filter(spectrumstatsnap, tidalStage == "1_HW")
ratio.blue <- input1$ratio.blue
depth <- input1$depth
line1model <- lm(formula = log(ratio.blue) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df1 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 2_HW_HWxLW
input2 <- filter(spectrumstatsnap, tidalStage == "2_HW_HWxLW")
ratio.blue <- input2$ratio.blue
depth <- input2$depth
line1model <- lm(formula = log(ratio.blue) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df2 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 3_HWxLW
input3 <- filter(spectrumstatsnap, tidalStage == "3_HWxLW")
ratio.blue <- input3$ratio.blue
depth <- input3$depth
line1model <- lm(formula = log(ratio.blue) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df3 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 4_HWxLW_LW
input4 <- filter(spectrumstatsnap, tidalStage == "4_HWxLW_LW")
ratio.blue <- input4$ratio.blue
depth <- input4$depth
line1model <- lm(formula = log(ratio.blue) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df4 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 5_LW
input5 <- filter(spectrumstatsnap, tidalStage == "5_LW")
ratio.blue <- input5$ratio.blue
depth <- input5$depth
line1model <- lm(formula = log(ratio.blue) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df5 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 6_LW_LWxHW
input6 <- filter(spectrumstatsnap, tidalStage == "6_LW_LWxHW")
ratio.blue <- input6$ratio.blue
depth <- input6$depth
line1model <- lm(formula = log(ratio.blue) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df6 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 7_LW_HW
input7 <- filter(spectrumstatsnap, tidalStage == "7_LW_HW")
ratio.blue <- input7$ratio.blue
depth <- input7$depth
line1model <- lm(formula = log(ratio.blue) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df7 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

colormap <- myPalette(8)
integrationplot <- ggplot(data=spectrumstatsnap, aes(x=ratio.blue, y=depth, group=tidalStage))
integrationplot <- integrationplot + geom_line(inherit.aes=F, data=df0, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[1], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df1, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[2], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df2, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[3], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df3, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[4], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df4, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[5], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df5, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[6], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df6, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[7], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df7, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[8], size=2, alpha=0.5)
integrationplot <- integrationplot + geom_point(aes(shape=tidalStage, color=tidalStage, size=tidalStage, fill=tidalStage)) + scale_size_manual(values=c(2,2,2,2,2,2,2,2)) + scale_shape_manual(values=c(21,21,21,21,21,21,21,21)) + scale_color_manual(values=c('#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F', '#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F')) + scale_fill_manual(values=colormap)
integrationplot <- integrationplot + theme_bw() + labs(title = "Attenuation of the subaerial spectrum throughout the water column, per tidal stage") + theme(plot.title = element_text(size = 12, face = "bold", color = "blue", hjust = 0.5))#+ scale_y_reverse()
integrationplot <- integrationplot + scale_y_continuous(name="Depth spectrometer (m)") + scale_y_reverse(name="Depth spectrometer (m)", limits=c(3.25, 0.5)) + scale_x_continuous(name="Ratio subaqueous to subaerial spectra", limits=c(0, 0.25), breaks=seq(min(0), max(1), by = 0.1))
print(integrationplot) # /outputdata/spectra/final_plots/Attenuation_Depth_Ratio_TidalStage_blue 8x5 is nice

# GROUPPED PLOT DEPTH NORMALIZED (nice for attenuation question) FOR GREEN LIGHT
# Trend 0_Test
input0 <- filter(spectrumstatsnap, tidalStage == "0_Test")
ratio.green <- input0$ratio.green
depth <- input0$depth
line1model <- lm(formula = log(ratio.green) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df0 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df0 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df0$ratio_exp[[which(df0$depthvalues==3.640)]] # 0.09176563

# Trend 1_HW
input1 <- filter(spectrumstatsnap, tidalStage == "1_HW")
ratio.green <- input1$ratio.green
depth <- input1$depth
line1model <- lm(formula = log(ratio.green) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df1 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df1 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df1$ratio_exp[[which(df1$depthvalues==3.760)]] # 0.06787643

# Trend 2_HW_HWxLW
input2 <- filter(spectrumstatsnap, tidalStage == "2_HW_HWxLW")
ratio.green <- input2$ratio.green
depth <- input2$depth
line1model <- lm(formula = log(ratio.green) ~ depth)
summary(line1model) 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df2 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df2 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df2$ratio_exp[[which(df2$depthvalues==3.390)]] # 0.02500131

# Trend 3_HWxLW
input3 <- filter(spectrumstatsnap, tidalStage == "3_HWxLW")
ratio.green <- input3$ratio.green
depth <- input3$depth
line1model <- lm(formula = log(ratio.green) ~ depth)
summary(line1model) # 0.9071  
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df3 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df3 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df3$ratio_exp[[which(df3$depthvalues==2.805)]] # 0.1290265 doet het voor some reason niet bij 2.800

# Trend 4_HWxLW_LW
input4 <- filter(spectrumstatsnap, tidalStage == "4_HWxLW_LW")
ratio.green <- input4$ratio.green
depth <- input4$depth
line1model <- lm(formula = log(ratio.green) ~ depth)
summary(line1model) # 0.9051 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df4 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df4 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df4$ratio_exp[[which(df4$depthvalues==2.370)]] # 0.09205843

# Trend 5_LW
input5 <- filter(spectrumstatsnap, tidalStage == "5_LW")
ratio.green <- input5$ratio.green
depth <- input5$depth
line1model <- lm(formula = log(ratio.green) ~ depth)
summary(line1model) # 0.907
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df5 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df5 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df5$ratio_exp[[which(df5$depthvalues==2.120)]] # 0.05880396

# Trend 6_LW_LWxHW
input6 <- filter(spectrumstatsnap, tidalStage == "6_LW_LWxHW")
ratio.green <- input6$ratio.green
depth <- input6$depth
line1model <- lm(formula = log(ratio.green) ~ depth)
summary(line1model) # 0.9809 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df6 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df6 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df6$ratio_exp[[which(df6$depthvalues==2.970)]] # 0.07465363

# Trend 7_LW_HW
input7 <- filter(spectrumstatsnap, tidalStage == "7_LW_HW")
ratio.green <- input7$ratio.green
depth <- input7$depth
line1model <- lm(formula = log(ratio.green) ~ depth)
summary(line1model) # 0.9764
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df7 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df7 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df7$ratio_exp[[which(df7$depthvalues==3.340)]] # 0.05278141

colormap <- myPalette(8)
integrationplot <- ggplot(data=spectrumstatsnap, aes(x=ratio.green, y=depth, group=tidalStage))
integrationplot <- integrationplot + geom_line(inherit.aes=F, data=df0, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[1], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df1, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[2], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df2, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[3], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df3, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[4], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df4, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[5], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df5, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[6], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df6, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[7], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df7, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[8], size=2, alpha=0.5)
integrationplot <- integrationplot + geom_point(aes(shape=tidalStage, color=tidalStage, size=tidalStage, fill=tidalStage)) + scale_size_manual(values=c(2,2,2,2,2,2,2,2)) + scale_shape_manual(values=c(21,21,21,21,21,21,21,21)) + scale_color_manual(values=c('#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F', '#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F')) + scale_fill_manual(values=colormap)
integrationplot <- integrationplot + theme_bw() + labs(title = "Attenuation of the subaerial spectrum throughout the water column, per tidal stage") + theme(plot.title = element_text(size = 12, face = "bold", color = "green4", hjust = 0.5))#+ scale_y_reverse()
integrationplot <- integrationplot + scale_y_continuous(name="Depth spectrometer (m)") + scale_y_reverse(name="Depth spectrometer (m)", limits=c(3.25, 0.5)) + scale_x_continuous(name="Ratio subaqueous to subaerial spectra", limits=c(0, 0.25), breaks=seq(min(0), max(1), by = 0.1))
print(integrationplot) # /outputdata/spectra/final_plots/Attenuation_Depth_Ratio_TidalStage_green 8x5 is nice

# GROUPPED PLOT DEPTH NORMALIZED (nice for attenuation question) FOR RED LIGHT
# Trend 0_Test
input0 <- filter(spectrumstatsnap, tidalStage == "0_Test")
ratio.red <- input0$ratio.red
depth <- input0$depth
line1model <- lm(formula = log(ratio.red) ~ depth)
summary(line1model) #0.998
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df0 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 1_HW
input1 <- filter(spectrumstatsnap, tidalStage == "1_HW")
ratio.red <- input1$ratio.red
depth <- input1$depth
line1model <- lm(formula = log(ratio.red) ~ depth)
summary(line1model) #0.9653
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df1 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 2_HW_HWxLW
input2 <- filter(spectrumstatsnap, tidalStage == "2_HW_HWxLW")
ratio.red <- input2$ratio.red
depth <- input2$depth
line1model <- lm(formula = log(ratio.red) ~ depth)
summary(line1model) # 0.9893 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df2 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 3_HWxLW
input3 <- filter(spectrumstatsnap, tidalStage == "3_HWxLW")
ratio.red <- input3$ratio.red
depth <- input3$depth
line1model <- lm(formula = log(ratio.red) ~ depth)
summary(line1model) # 0.9282
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df3 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 4_HWxLW_LW
input4 <- filter(spectrumstatsnap, tidalStage == "4_HWxLW_LW")
ratio.red <- input4$ratio.red
depth <- input4$depth
line1model <- lm(formula = log(ratio.red) ~ depth)
summary(line1model) # 0.9286 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df4 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 5_LW
input5 <- filter(spectrumstatsnap, tidalStage == "5_LW")
ratio.red <- input5$ratio.red
depth <- input5$depth
line1model <- lm(formula = log(ratio.red) ~ depth)
summary(line1model) # 0.9188
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df5 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 6_LW_LWxHW
input6 <- filter(spectrumstatsnap, tidalStage == "6_LW_LWxHW")
ratio.red <- input6$ratio.red
depth <- input6$depth
line1model <- lm(formula = log(ratio.red) ~ depth)
summary(line1model) # 0.9855 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df6 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Trend 7_LW_HW
input7 <- filter(spectrumstatsnap, tidalStage == "7_LW_HW")
ratio.red <- input7$ratio.red
depth <- input7$depth
line1model <- lm(formula = log(ratio.red) ~ depth)
summary(line1model) # 0.9801
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df7 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

colormap <- myPalette(8)
integrationplot <- ggplot(data=spectrumstatsnap, aes(x=ratio.red, y=depth, group=tidalStage))
integrationplot <- integrationplot + geom_line(inherit.aes=F, data=df0, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[1], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df1, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[2], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df2, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[3], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df3, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[4], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df4, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[5], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df5, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[6], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df6, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[7], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df7, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[8], size=2, alpha=0.5)
integrationplot <- integrationplot + geom_point(aes(shape=tidalStage, color=tidalStage, size=tidalStage, fill=tidalStage)) + scale_size_manual(values=c(2,2,2,2,2,2,2,2)) + scale_shape_manual(values=c(21,21,21,21,21,21,21,21)) + scale_color_manual(values=c('#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F', '#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F')) + scale_fill_manual(values=colormap)
integrationplot <- integrationplot + theme_bw() + labs(title = "Attenuation of the subaerial spectrum throughout the water column, per tidal stage") + theme(plot.title = element_text(size = 12, face = "bold", color = "red", hjust = 0.5))#+ scale_y_reverse()
integrationplot <- integrationplot + scale_y_continuous(name="Depth spectrometer (m)") + scale_y_reverse(name="Depth spectrometer (m)", limits=c(3.25, 0.5)) + scale_x_continuous(name="Ratio subaqueous to subaerial spectra", limits=c(0, 0.25), breaks=seq(min(0), max(1), by = 0.1))
print(integrationplot) # /outputdata/spectra/final_plots/Attenuation_Depth_Ratio_TidalStage_red 8x5 is nice

# GROUPPED PLOT DEPTH NORMALIZED (nice for attenuation question) FOR IR LIGHT
# Trend 0_Test
input0 <- filter(spectrumstatsnap, tidalStage == "0_Test")
ratio.IR <- input0$ratio.IR
depth <- input0$depth
line1model <- lm(formula = log(ratio.IR) ~ depth)
summary(line1model) #0.9856
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df0 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df0 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df0$ratio_exp[[which(df0$depthvalues==3.640)]] # 0.001323442

# Trend 1_HW
input1 <- filter(spectrumstatsnap, tidalStage == "1_HW")
ratio.IR <- input1$ratio.IR
depth <- input1$depth
line1model <- lm(formula = log(ratio.IR) ~ depth)
summary(line1model) #0.9751 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df1 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df1 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df1$ratio_exp[[which(df1$depthvalues==3.760)]] # 0.00073648

# Trend 2_HW_HWxLW
input2 <- filter(spectrumstatsnap, tidalStage == "2_HW_HWxLW")
ratio.IR <- input2$ratio.IR
depth <- input2$depth
line1model <- lm(formula = log(ratio.IR) ~ depth)
summary(line1model) # 0.9795 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df2 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df2 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df2$ratio_exp[[which(df2$depthvalues==3.390)]] #0.0004765312

# Trend 3_HWxLW
input3 <- filter(spectrumstatsnap, tidalStage == "3_HWxLW")
ratio.IR <- input3$ratio.IR
depth <- input3$depth
line1model <- lm(formula = log(ratio.IR) ~ depth)
summary(line1model) # 0.9568 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df3 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df3 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df3$ratio_exp[[which(df3$depthvalues==2.805)]] #0.002306064

# Trend 4_HWxLW_LW
input4 <- filter(spectrumstatsnap, tidalStage == "4_HWxLW_LW")
ratio.IR <- input4$ratio.IR
depth <- input4$depth
line1model <- lm(formula = log(ratio.IR) ~ depth)
summary(line1model) #0.9739 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df4 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df4 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df4$ratio_exp[[which(df4$depthvalues==2.370)]] #0.002441816

# Trend 5_LW
input5 <- filter(spectrumstatsnap, tidalStage == "5_LW")
ratio.IR <- input5$ratio.IR
depth <- input5$depth
line1model <- lm(formula = log(ratio.IR) ~ depth)
summary(line1model) # 0.9332 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df5 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df5 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df5$ratio_exp[[which(df5$depthvalues==2.120)]] # 0.002105753

# Trend 6_LW_LWxHW
input6 <- filter(spectrumstatsnap, tidalStage == "6_LW_LWxHW")
ratio.IR <- input6$ratio.IR
depth <- input6$depth
line1model <- lm(formula = log(ratio.IR) ~ depth)
summary(line1model) # 0.984 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df6 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df6 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df6$ratio_exp[[which(df6$depthvalues==2.970)]] # 0.001469233

# Trend 7_LW_HW
input7 <- filter(spectrumstatsnap, tidalStage == "7_LW_HW")
ratio.IR <- input7$ratio.IR
depth <- input7$depth
line1model <- lm(formula = log(ratio.IR) ~ depth)
summary(line1model) # 0.9684 
depthvalues <- seq(0,3.25,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df7 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)

# Voor model
depthvalues <- seq(0,3.76,0.005)
ratio_exp <- exp(predict(line1model, list(depth=depthvalues)))
df7 <- tibble(depthvalues=depthvalues, ratio_exp=ratio_exp)
# Als max. 3.250
df7$ratio_exp[[which(df7$depthvalues==3.340)]] # 0.0008737337

colormap <- myPalette(8)
integrationplot <- ggplot(data=spectrumstatsnap, aes(x=ratio.IR, y=depth, group=tidalStage))
integrationplot <- integrationplot + geom_line(inherit.aes=F, data=df0, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[1], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df1, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[2], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df2, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[3], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df3, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[4], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df4, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[5], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df5, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[6], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df6, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[7], size=2, alpha=0.5) + geom_line(inherit.aes=F, data=df7, mapping=aes(x=ratio_exp, y=depthvalues), color=colormap[8], size=2, alpha=0.5)
integrationplot <- integrationplot + geom_point(aes(shape=tidalStage, color=tidalStage, size=tidalStage, fill=tidalStage)) + scale_size_manual(values=c(2,2,2,2,2,2,2,2)) + scale_shape_manual(values=c(21,21,21,21,21,21,21,21)) + scale_color_manual(values=c('#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F', '#0F0F0F','#0F0F0F', '#0F0F0F', '#0F0F0F')) + scale_fill_manual(values=colormap)
integrationplot <- integrationplot + theme_bw() + labs(title = "Attenuation of the subaerial spectrum throughout the water column, per tidal stage") + theme(plot.title = element_text(size = 12, face = "bold", color = "#380000", hjust = 0.5))#+ scale_y_reverse()
integrationplot <- integrationplot + scale_y_continuous(name="Depth spectrometer (m)") + scale_y_reverse(name="Depth spectrometer (m)", limits=c(3.25, 0.5)) + scale_x_continuous(name="Ratio subaqueous to subaerial spectra", limits=c(0, 0.05), breaks=seq(min(0), max(0.05), by = 0.01))

print(integrationplot) # /outputdata/spectra/final_plots/Attenuation_Depth_Ratio_TidalStage_darkredIR 8x5 is nice

###MANUSCRIPT FIGURES###
#FIGURE 3: timing and position of tide
# Let's make a nicer plot for waterlevel vs measurements for methodology
timeplot <- ggplot(data = waterheight_smoothed, aes(x=DateTime_CEST, y = nap_in_cm)) + 
  geom_line(lwd=2, color="lightblue", alpha=0.75) + 
  geom_point(data = spectrumstatsnap, mapping = aes(x=DateTime_CEST,y=nap_in_cm),color="white", size=1) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1)) +
  labs(x="DateTime (CEST) 2022") + 
  scale_y_continuous(name="Vertical position of spectrometer (N.A.P. cm)", limits=c(-350, 150)) +
 annotate('rect', xmin=min(waterheight_smoothed$DateTime_CEST), xmax=max(waterheight_smoothed$DateTime_CEST), ymin=-300, ymax=-290, alpha=.2, fill='grey')
print(timeplot) # /outputdata/spectra/final_plots/SpectrometerMeasurementsOverTimeNAP
ggsave(paste("Figure3_timing_position-spectrometer.tiff",sep=""), plot = last_plot(), width = 10, height = 12)

#Figure 4: plot spectra
###Column 1: 1_HW
#Curve 1: Sky 1_HW_35 2022-10-26 09:50:03 CEST at 75.610000 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_1_HW[[11]][[1]]$wavelength, y=spectra_W_1_HW[[11]][[1]]$copy_calSky), color="#cc6677") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
  axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
  plot.background = element_blank())
ggsave(paste("1_HW_35_75cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 2: Water 1_HW_38 2022-10-26 09:50:37 CEST at 0.210000 cm NAP
ggplot() + # 
  geom_point(aes(x=spectra_W_1_HW[[11]][[15]]$wavelength, y=spectra_W_1_HW[[11]][[15]]$intensity), color="#44aa99") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),)
ggsave(paste("1_HW_38_0cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 3: Water 1_HW_90 2022-10-26 10:13:58 CEST at -100.408333 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_1_HW[[11]][[54]]$wavelength, y=spectra_W_1_HW[[11]][[54]]$intensity), color="#DDCC77") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),)
ggsave(paste("1_HW_90_-100cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 4: Water 1_HW_86 2022-10-26 10:12:55 CEST at -199.913333 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_1_HW[[11]][[50]]$wavelength, y=spectra_W_1_HW[[11]][[50]]$intensity), color="#6699cc") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),)
ggsave(paste("1_HW_86_-200cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Plot ALL 1_HW
ggplot() +
  geom_point(aes(x=spectra_W_1_HW[[11]][[1]]$wavelength, y=spectra_W_1_HW[[11]][[1]]$copy_calSky), color="#cc6677") +
  geom_point(aes(x=spectra_W_1_HW[[11]][[15]]$wavelength, y=spectra_W_1_HW[[11]][[15]]$intensity), color="#44aa99") +
  geom_point(aes(x=spectra_W_1_HW[[11]][[54]]$wavelength, y=spectra_W_1_HW[[11]][[54]]$intensity), color="#DDCC77") +
  geom_point(aes(x=spectra_W_1_HW[[11]][[50]]$wavelength, y=spectra_W_1_HW[[11]][[50]]$intensity), color="#6699cc") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank())
ggsave(paste("1_HW_ALL_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)

###Column 2: 2_HW_HWxLW
#Curve 1: Sky 2_HW_HWxLW_129 2022-10-26 11:35:51 CEST at 21.920000 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_2_HW_HWxLW[[11]][[27]]$wavelength, y=spectra_W_2_HW_HWxLW[[11]][[27]]$copy_calSky), color="#cc6677") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),)
ggsave(paste("2_HW_HWxLW_129_21cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 2: Water 2_HW_HWxLW_125 2022-10-26 11:33:40 CESt at -3.250000 cm NAP
ggplot() + # 
  geom_point(aes(x=spectra_W_2_HW_HWxLW[[11]][[25]]$wavelength, y=spectra_W_2_HW_HWxLW[[11]][[25]]$intensity), color="#44aa99") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),)
ggsave(paste("2_HW_HWxLW_125_3cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 3: Water 2_HW_HWxLW_135 2022-10-26 11:36:49 CEST at -104.826667 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_2_HW_HWxLW[[11]][[33]]$wavelength, y=spectra_W_2_HW_HWxLW[[11]][[33]]$intensity), color="#DDCC77") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),)
ggsave(paste("2_HW_HWxLW_135_-104cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 4: Water 2_HW_HWxLW_140 2022-10-26 11:37:36 CEST at -208.871667 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_2_HW_HWxLW[[11]][[38]]$wavelength, y=spectra_W_2_HW_HWxLW[[11]][[38]]$intensity), color="#6699cc") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),)
ggsave(paste("2_HW_HWxLW_140_-208cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#SUM 2_HW_HWxLW
ggplot() +
  geom_point(aes(x=spectra_W_2_HW_HWxLW[[11]][[27]]$wavelength, y=spectra_W_2_HW_HWxLW[[11]][[27]]$copy_calSky), color="#cc6677") +
  geom_point(aes(x=spectra_W_2_HW_HWxLW[[11]][[25]]$wavelength, y=spectra_W_2_HW_HWxLW[[11]][[25]]$intensity), color="#44aa99") +
  geom_point(aes(x=spectra_W_2_HW_HWxLW[[11]][[33]]$wavelength, y=spectra_W_2_HW_HWxLW[[11]][[33]]$intensity), color="#DDCC77") +
  geom_point(aes(x=spectra_W_2_HW_HWxLW[[11]][[38]]$wavelength, y=spectra_W_2_HW_HWxLW[[11]][[38]]$intensity), color="#6699cc") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank())
ggsave(paste("2_HW_HWxLW_SUM_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)

###Column 3: 5_LW
#Curve 1: Sky 5_LW_239 2022-10-26 15:57:35 CEST at -85.241667 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_5_LW[[11]][[1]]$wavelength, y=spectra_W_5_LW[[11]][[1]]$copy_calSky), color="#cc6677") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),)
ggsave(paste("5_LW_239_-85cm_SKY_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 2: Water 5_LW_239 2022-10-26 15:57:35 CEST at -85.241667 cm NAP
ggplot() + # 
  geom_point(aes(x=spectra_W_5_LW[[11]][[1]]$wavelength, y=spectra_W_5_LW[[11]][[1]]$intensity), color="#44aa99") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),)
ggsave(paste("5_LW_239_-85cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 3: Water 5_LW_241 2022-10-26 15:58:08 CEST at -112.403333 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_5_LW[[11]][[3]]$wavelength, y=spectra_W_5_LW[[11]][[3]]$intensity), color="#DDCC77") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),)
ggsave(paste("5_LW_241_-112cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 4: Water 5_LW_246 2022-10-26 15:59:25 CEST at -206.231667 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_5_LW[[11]][[8]]$wavelength, y=spectra_W_5_LW[[11]][[8]]$intensity), color="#6699cc") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),)
ggsave(paste("5_LW_246_-206cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#SUM 5_LW
ggplot() +
  geom_point(aes(x=spectra_W_5_LW[[11]][[1]]$wavelength, y=spectra_W_5_LW[[11]][[1]]$copy_calSky), color="#cc6677") +
  geom_point(aes(x=spectra_W_5_LW[[11]][[1]]$wavelength, y=spectra_W_5_LW[[11]][[1]]$intensity), color="#44aa99") +
  geom_point(aes(x=spectra_W_5_LW[[11]][[3]]$wavelength, y=spectra_W_5_LW[[11]][[3]]$intensity), color="#DDCC77") +
  geom_point(aes(x=spectra_W_5_LW[[11]][[8]]$wavelength, y=spectra_W_5_LW[[11]][[8]]$intensity), color="#6699cc") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank())
ggsave(paste("5_LW_SUM_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)

###Column 4: 7_LW_HW
#Curve 1: Sky 7_LW_HW_316 2022-10-26 17:59:13 CEST at 37.31666667 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_7_LW_HW[[11]][[1]]$wavelength, y=spectra_W_7_LW_HW[[11]][[1]]$copy_calSky), color="#cc6677") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),)
ggsave(paste("7_LW_HW_316_37cm_SKY_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 2: Water 7_LW_HW_370 2022-10-26 18:12:19 CEST at 0.02666667 cm NAP
ggplot() + # 
  geom_point(aes(x=spectra_W_7_LW_HW[[11]][[53]]$wavelength, y=spectra_W_7_LW_HW[[11]][[53]]$intensity), color="#44aa99") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),)
ggsave(paste("7_LW_HW_370_0cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 3: Water 7_LW_HW_351 2022-10-26 18:07:42 CEST at -102.02666667 cm NAO
ggplot() + 
  geom_point(aes(x=spectra_W_7_LW_HW[[11]][[34]]$wavelength, y=spectra_W_7_LW_HW[[11]][[34]]$intensity), color="#DDCC77") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        axis.title.x = element_blank(), axis.title.y = element_blank(), axis.text=element_blank(), axis.ticks = element_blank(),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),)
ggsave(paste("7_LW_HW_351_-102cm_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#Curve 4: Water 7_LW_HW_356 2022-10-26 18:08:46 CEST at -202.04166667 cm NAP
ggplot() + 
  geom_point(aes(x=spectra_W_7_LW_HW[[11]][[39]]$wavelength, y=spectra_W_7_LW_HW[[11]][[39]]$intensity), color="#6699cc") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        plot.background = element_blank(),
        panel.background = element_rect(fill = "azure2",
                                        colour = "azure2",
                                        size = 0.5, linetype = "solid"),
        axis.title = element_text(size=20), axis.text = element_text(size=16)) +
  xlab("Wavelength [nm]") +
  ylab("Light intensity [mW/m2 nm]")
ggsave(paste("7_LW_HW_356_-202cm_V3.tiff",sep=""), plot = last_plot(), width = 4, height = 4)
#SUM 7_LW_HW
ggplot() +
  geom_point(aes(x=spectra_W_7_LW_HW[[11]][[1]]$wavelength, y=spectra_W_7_LW_HW[[11]][[1]]$copy_calSky), color="#cc6677") +
  geom_point(aes(x=spectra_W_7_LW_HW[[11]][[53]]$wavelength, y=spectra_W_7_LW_HW[[11]][[53]]$intensity), color="#44aa99") +
  geom_point(aes(x=spectra_W_7_LW_HW[[11]][[34]]$wavelength, y=spectra_W_7_LW_HW[[11]][[34]]$intensity), color="#DDCC77") +
  geom_point(aes(x=spectra_W_7_LW_HW[[11]][[39]]$wavelength, y=spectra_W_7_LW_HW[[11]][[39]]$intensity), color="#6699cc") +
  xlim(350,750) + ylim(0,310) +
  theme_classic() +
  theme(legend.position = "none", panel.border = element_rect(colour = "black", fill=NA, linewidth = 1))
ggsave(paste("7_LW_HW_SUM_V1.tiff",sep=""), plot = last_plot(), width = 4, height = 4)

# Add to specstatsnap (make new one just in case)
#spectrumstatsnap_withcalSky_copy is a copy in case something goes wrong:
#spectrumstatsnap_withcalSky <- spectrumstatsnap_withcalSky_copy

spectrumstatsnap_withcalSky <- as_tibble(spectrumstatsnap_withcalSky)

green290 <- c(0.09177, 0.06788, 0.02500, 0.12903, 0.09206, 0.05880, 0.07465, 0.05278)
NIR290 <- c(0.00132, 0.00074, 0.00048, 0.00231, 0.00244, 0.00211, 0.00147, 0.00087)
VIS290 <- c(0.04953, 0.03506, 0.01343, 0.07419, 0.05325, 0.03512, 0.04116, 0.02783)

modelledpoints <- spectrumstatsnap_withcalSky[346, ] # 0
modelledpoints[(nrow(modelledpoints)+1), ] <- spectrumstatsnap_withcalSky[349, ] #1
modelledpoints[(nrow(modelledpoints)+1), ] <- spectrumstatsnap_withcalSky[351, ] #2
modelledpoints[(nrow(modelledpoints)+1), ] <- spectrumstatsnap_withcalSky[355, ] #3
modelledpoints[(nrow(modelledpoints)+1), ] <- spectrumstatsnap_withcalSky[362, ] #4
modelledpoints[(nrow(modelledpoints)+1), ] <- spectrumstatsnap_withcalSky[371, ] #5
modelledpoints[(nrow(modelledpoints)+1), ] <- spectrumstatsnap_withcalSky[381, ] #6
modelledpoints[(nrow(modelledpoints)+1), ] <- spectrumstatsnap_withcalSky[387, ] #7
modelledpoints290 <- modelledpoints
modelledpoints270 <- modelledpoints
modelledpoints250 <- modelledpoints

modelledpoints290$nap_in_cm <- -290
modelledpoints270$nap_in_cm <- -270
modelledpoints250$nap_in_cm <- -250

# For green 290
for (i in 1:nrow(modelledpoints290)) {
  attenuationvalue <- green290[i]
  intnew <- modelledpoints290$int.green[i]*attenuationvalue
  modelledpoints290$int.green[i] <- intnew # Overwrite skymean with underwater
}
for (i in 1:nrow(modelledpoints290)) {
  attenuationvalue <- NIR290[i]
  intnew <- modelledpoints290$int.IR[i]*attenuationvalue
  modelledpoints290$int.IR[i] <- intnew # Overwrite skymean with underwater
}
for (i in 1:nrow(modelledpoints290)) {
  attenuationvalue <- VIS290[i]
  intnew <- modelledpoints290$int.full[i]*attenuationvalue
  modelledpoints290$int.full[i] <- intnew # Overwrite skymean with underwater
}
# Add to spectrumstatsnap_withCalSky
spectrumstatsnap_withcalSky <- add_row(spectrumstatsnap_withcalSky, modelledpoints290)

###CUMULATIVE LIGHT EXPOSURE CALCULATIONS
#Check how many spectra has been measured for ever 20 cm interval around each sample
samplenap <- data.frame(matrix(ncol=8, nrow=21))
rownames(samplenap) <- timespan$nap_in_cm
tidal_names <- c("0_Test", "1_HW", "2_HW_HWxLW", "3_HWxLW", "4_HWxLW_LW", "5_LW", "6_LW_LWxHW", "7_LW_HW")
colnames(samplenap) <- tidal_names
samplenap[is.na(samplenap)] <- 0
as.numeric(rownames(samplenap))
for (row in 1:nrow(spectrumstatsnap)) {
  rowdata = spectrumstatsnap[row, ]
  NAP = rowdata$nap_in_cm
  profile = rowdata$tidalStage 
  for (samplepos in rownames(samplenap)) {
    samplepos_numeric = as.numeric(samplepos)
    if (NAP > samplepos_numeric-10 & NAP <= samplepos_numeric + 10) 
      {samplenap[samplepos, profile] <- samplenap[samplepos, profile] + 1 }
  }
}
#Insert light exposure per sample depth
cumlight <- data.frame(matrix(ncol=8, nrow=21))
rownames(cumlight) <- timespan$nap_in_cm
tidal_names <- c("0_Test", "1_HW", "2_HW_HWxLW", "3_HWxLW", "4_HWxLW_LW", "5_LW", "6_LW_LWxHW", "7_LW_HW")
colnames(cumlight) <- tidal_names
cumlight[is.na(cumlight)] <- 0
as.numeric(rownames(cumlight))
for (row in 1:nrow(spectrumstatsnap)) {
  rowdata = spectrumstatsnap[row, ]
  NAP = rowdata$nap_in_cm
  profile = rowdata$tidalStage
  for (samplepos in rownames(cumlight)) {
    samplepos_numeric = as.numeric(samplepos)
    ifelse (NAP > samplepos_numeric-10 & NAP <= samplepos_numeric + 10,
    cumlight[samplepos, profile] <- cumlight[samplepos, profile] + rowdata$int.full,
    0)
  }
} 
#fill empty positions with with sky spectra
for (row in 1:nrow(spectrumstatsnap)) {
  rowdata = spectrumstatsnap[row, ]
  profile = rowdata$tidalStage
  for (samplepos in rownames(cumlight)) {
    samplepos_numeric = as.numeric(samplepos)
    if (cumlight[samplepos, profile]==0) 
      {cumlight[samplepos, profile] <- rowdata$int.sky}
  }
} 
#remove rows (sample depths) with no or no complete water spectrometer datasets: -300;-290;-270;-250;-230
cumlight <- cumlight[-c(1,2,3,4,21),]
#Set all 0 values in samplenap df to 1 because there is always 1 sky spectra
samplenap[samplenap==0] <- samplenap[samplepos, profile] + 1
#remove rows so that length is equal to lenght of cumlight df
samplenap <- samplenap[-c(1,2,3,4,21),]
#calculate mean per sample depth
cum <- cumlight/samplenap 
#sum row values and create new column 
cum <- cum %>%
  mutate(cum_light = rowSums(.))

###Create donut charts for figure 4 manuscript
#Create dataframe with light intensity 
library("ggplot2")
#sample 1: -210 cm
sample1 <- data.frame(category=c("cum_sample","maximum"), count=c(cum[1,9], cum[16,9]))
sample1$percentage <- NA
sample1[1,3] = round(sample1[1,2]/sample1[2,2], digits=2)
sample1[2,3] = 1
sample1$ymin<- NA
sample1$ymax <- NA
sample1[1,4] <- 0
sample1[2,4] <- sample1[1,3]
sample1[1,5] <- sample1[1,3]
sample1[2,5] <- sample1[2,3]
ggplot(sample1, aes(ymax=ymax, ymin=ymin, xmax=4, xmin=3, fill=category)) +
  geom_rect() +
  #geom_label( x=3.5, aes(y=labelPosition, label=label), size=6) +
  scale_fill_brewer(palette=7, direction=-1) +
  scale_color_brewer(palette=7) +
  coord_polar(theta="y") +
  xlim(c(0.5,4)) +
  theme_void() +
  theme(legend.position = "none")
ggsave("doughnut_sample-210cm_11percent.png", plot=last_plot(), width=4, height=4)
#sample 4: -150 cm
sample4 <- data.frame(category=c("cum_sample","maximum"), count=c(cum[4,9], cum[16,9]))
sample4$percentage <- NA
sample4[1,3] = round(sample4[1,2]/sample4[2,2], digits=2)
sample4[2,3] = 1
sample4$ymin<- NA
sample4$ymax <- NA
sample4[1,4] <- 0
sample4[2,4] <- sample4[1,3]
sample4[1,5] <- sample4[1,3]
sample4[2,5] <- sample4[2,3]
ggplot(sample4, aes(ymax=ymax, ymin=ymin, xmax=4, xmin=3, fill=category)) +
  geom_rect() +
  scale_fill_brewer(palette=7,direction=-1) +
  scale_color_brewer(palette=7) +
  coord_polar(theta="y") +
  xlim(c(0.5,4)) +
  theme_void() +
  theme(legend.position = "none")
ggsave("doughnut_sample-150cm_19percent.png", plot=last_plot(), width=4, height=4)
#sample 6: -110 cm
sample6 <- data.frame(category=c("cum_sample","maximum"), count=c(cum[6,9], cum[16,9]))
sample6$percentage <- NA
sample6[1,3] = round(sample6[1,2]/sample6[2,2], digits=2)
sample6[2,3] = 1
sample6$ymin<- NA
sample6$ymax <- NA
sample6[1,4] <- 0
sample6[2,4] <- sample6[1,3]
sample6[1,5] <- sample6[1,3]
sample6[2,5] <- sample6[2,3]
ggplot(sample6, aes(ymax=ymax, ymin=ymin, xmax=4, xmin=3, fill=category)) +
  geom_rect() +
  scale_fill_brewer(palette=7,direction=-1) +
  scale_color_brewer(palette=7) +
  coord_polar(theta="y") +
  xlim(c(0.5,4)) +
  theme_void() +
  theme(legend.position = "none")
ggsave("doughnut_sample-110cm_32percent.png", plot=last_plot(), width=4, height=4)
#sample 9: -50 cm
sample9 <- data.frame(category=c("cum_sample","maximum"), count=c(cum[9,9], cum[16,9]))
sample9$percentage <- NA
sample9[1,3] = round(sample9[1,2]/sample9[2,2], digits=2)
sample9[2,3] = 1
sample9$ymin<- NA
sample9$ymax <- NA
sample9[1,4] <- 0
sample9[2,4] <- sample9[1,3]
sample9[1,5] <- sample9[1,3]
sample9[2,5] <- sample9[2,3]
ggplot(sample9, aes(ymax=ymax, ymin=ymin, xmax=4, xmin=3, fill=category)) +
  geom_rect() +
  scale_fill_brewer(palette=7,direction=-1) +
  scale_color_brewer(palette=7) +
  coord_polar(theta="y") +
  xlim(c(0.5,4)) +
  theme_void() +
  theme(legend.position = "none")
ggsave("doughnut_sample-50cm_64percent.png", plot=last_plot(), width=4, height=4)
#sample 11: -10 cm
sample11 <- data.frame(category=c("cum_sample","maximum"), count=c(cum[11,9], cum[16,9]))
sample11$percentage <- NA
sample11[1,3] = round(sample11[1,2]/sample11[2,2], digits=2)
sample11[2,3] = 1
sample11$ymin<- NA
sample11$ymax <- NA
sample11[1,4] <- 0
sample11[2,4] <- sample11[1,3]
sample11[1,5] <- sample11[1,3]
sample11[2,5] <- sample11[2,3]
ggplot(sample11, aes(ymax=ymax, ymin=ymin, xmax=4, xmin=3, fill=category)) +
  geom_rect() +
  scale_fill_brewer(palette=7,direction=-1) +
  scale_color_brewer(palette=7) +
  coord_polar(theta="y") +
  xlim(c(0.5,4)) +
  theme_void() +
  theme(legend.position = "none")
ggsave("doughnut_sample-10cm_82percent.png", plot=last_plot(), width=4, height=4)
#sample 13: +70 cm
sample13 <- data.frame(category=c("cum_sample","maximum"), count=c(cum[13,9], cum[16,9]))
sample13$percentage <- NA
sample13[1,3] = round(sample13[1,2]/sample13[2,2], digits=2)
sample13[2,3] = 1
sample13$ymin<- NA
sample13$ymax <- NA
sample13[1,4] <- 0
sample13[2,4] <- sample13[1,3]
sample13[1,5] <- sample13[1,3]
sample13[2,5] <- sample13[2,3]
ggplot(sample13, aes(ymax=ymax, ymin=ymin, xmax=4, xmin=3, fill=category)) +
  geom_rect() +
  scale_fill_brewer(palette=7,direction=-1) +
  scale_color_brewer(palette=7) +
  coord_polar(theta="y") +
  xlim(c(0.5,4)) +
  theme_void() +
  theme(legend.position = "none")
ggsave("doughnut_sample+70cm_98percent.png", plot=last_plot(), width=4, height=4)
#sample 14: +110 cm
sample14 <- data.frame(category=c("cum_sample","maximum"), count=c(cum[14,9], cum[16,9]))
sample14$percentage <- NA
sample14[1,3] = round(sample14[1,2]/sample14[2,2], digits=2)
sample14[2,3] = 1
sample14$ymin<- NA
sample14$ymax <- NA
sample14[1,4] <- 0
sample14[2,4] <- sample14[1,3]
sample14[1,5] <- sample14[1,3]
sample14[2,5] <- sample14[2,3]
ggplot(sample14, aes(ymax=ymax, ymin=ymin, xmax=4, xmin=3, fill=category)) +
  geom_rect() +
  scale_fill_brewer(palette=7,direction=-1) +
  scale_color_brewer(palette=7) +
  coord_polar(theta="y") +
  xlim(c(0.5,4)) +
  theme_void() +
  theme(legend.position = "none")
ggsave("doughnut_sample+110cm_100percent.png", plot=last_plot(), width=4, height=4)

###Express the cumulative power [W/m2] in energy [J/m2]
#Add columns to df to store tidal stage time intervals (Xduration) in sec and add column for energy (Xenergy)
#Fill duration columns with duration time in seconds
#Fill energy columns according to E[J/m2]=P[W/m2]*t[s] > energy column = cum_light*duration columns
cum_energy <- cum/1000 #convert from mW to W
cum_energy$zero_duration <- (76*3600) #46 min duration for stage 0 (see notebook AM)
cum_energy$one_duration <- (91*3600)
cum_energy$two_duration <- (86*3600)
cum_energy$three_duration <- (89*3600)
cum_energy$four_duration <- (93*3600)
cum_energy$five_duration <- (73*3600)
cum_energy$six_duration <- (63*3600)
cum_energy$seven_duration <- (61*3600)
cum_energy$zero_energy <- cum_energy$cum_light*cum_energy$zero_duration
cum_energy$one_energy <- cum_energy$cum_light*cum_energy$one_duration
cum_energy$two_energy <- cum_energy$cum_light*cum_energy$two_duration
cum_energy$three_energy <- cum_energy$cum_light*cum_energy$three_duration
cum_energy$four_energy <- cum_energy$cum_light*cum_energy$four_duration
cum_energy$five_energy <- cum_energy$cum_light*cum_energy$five_duration
cum_energy$six_energy <- cum_energy$cum_light*cum_energy$six_duration
cum_energy$seven_energy <- cum_energy$cum_light*cum_energy$seven_duration
#Calculate cum_energy per sample over total time span
cum_energy$cum_energy <- NA 
#Reorder columns
cum_energy <- cum_energy[, c(9,26,1,10,18,2,11,19,3,12,20,4,13,21,5,14,22,6,15,23,7,16,24,8,17,25)]
#Calculate cum_energy per sample over total time span (0_test has been left out here)
cum_energy$cum_energy <- rowSums(cum_energy[ , c(8,11,14,17,20,23,26)], na.rm=TRUE)
#Add column with luminescence sample depths(necessary to match it with luminescence data)
cum_energy$sample_depth <- NA
cum_energy$sample_depth <- c("-210","-190","-170","-150","-130","-110","-90","-70","-50","-30","-10","30","70","110","190","230")
cum_energy$sample_depth <- as.numeric(cum_energy$sample_depth)

###Import luminescence data for the four FS signals and all samples and create figure 6 bleaching paper
#Import all luminescence data
library(readxl)
luminescence <- read_excel("YOURWORKINGDIRECTIORYHERE/AllAgeModelResults_IQRfilter.xlsx")
#Create df that stores selection of the luminescence data needed
CAM_norm_exposure <- data.frame(matrix(nrow=64, ncol=6))
colnames(CAM_norm_exposure) <- c("position_NAP", "normalized_CAM_De", "normalized_CAM_De_error", "label", "Feldspar signal","cum_energy")
CAM_norm_exposure$position_NAP <- luminescence$position_NAP
CAM_norm_exposure$normalized_CAM_De <- luminescence$normalized_CAM_De
CAM_norm_exposure$normalized_CAM_De_error <- luminescence$normalized_CAM_De.Error
CAM_norm_exposure$label <- luminescence$label
CAM_norm_exposure$`Feldspar signal` <- luminescence$signal
#Amount of luminescence data and spectra data doesn't match > remove samples for which at least one of the datasets is empty
CAM_norm_exposure <- CAM_norm_exposure[-(1:12),]
cum_energy_fit <- cum_energy[-c(10,13,14,16),]
#Cum-energy_fit has a sample depth at 190 wilst luminescence df shows sample at 130 > 190 spectradata used
#for sample 130 which is okay because 130 sample was above water all day and 190 spectra as well
#Remove last four rows of luminescence data which represent the norm 1
CAM_norm_exposure <- CAM_norm_exposure[-c(49,50,51,52),]
#Fill cum_energy column by repeating each elemet four times because there are four FS signals
CAM_norm_exposure$cum_energy <- rep(cum_energy_fit$cum_energy, each=4)
#Remove accepted_' from column signal
CAM_norm_exposure <- CAM_norm_exposure %>% 
  mutate(`Feldspar signal` = str_remove_all(CAM_norm_exposure$`Feldspar signal`, "accepted_"))
view(CAM_norm_exposure)

#Plot figure: norm CAM as a function of cumulative light exposure expressed in energy [J/m2]
#KEEP IN MIND: for formula in fitting use x and y terms NOT in terms of variable names!!!
#read start sample values into R
start_sample <- read.csv("C:/Users/boer304/OneDrive - Wageningen University & Research/PhD/Academic/Rdata/BleachingI/start_sample_normalizedCAM.csv")
colnames(start_sample)[5] <- "Feldspar signal"
CAM_norm_exposure <- rbind(start_sample, CAM_norm_exposure)
ggplot(CAM_norm_exposure, aes(x=cum_energy, y=normalized_CAM_De, group=`Feldspar signal`,weight = 1/sqrt(normalized_CAM_De_error))) +
  geom_point(aes(shape=`Feldspar signal`, color=`Feldspar signal`, size=`Feldspar signal`)) +
  scale_shape_manual(name="Signal", labels=c("IRSL-50","pIRIR-150", "pIRIR-225", "pIRIR290"),
                     values=c(16,16,16,16)) +
  scale_color_manual(name="Signal", labels=c("IRSL-50","pIRIR-150", "pIRIR-225", "pIRIR290"),
                     values=c("#FEE391", "#FB9A29", "#CC4C02","#8B0000")) +
  scale_size_manual(name="Signal", labels=c("IRSL-50","pIRIR-150", "pIRIR-225", "pIRIR290"),
                    values=c(4,4,4,4)) +
  geom_pointrange(aes(ymin=normalized_CAM_De-normalized_CAM_De_error, 
                    ymax=normalized_CAM_De+normalized_CAM_De_error,color=factor(`Feldspar signal`))) +
  geom_hline(yintercept=1) +
  stat_smooth(data=filter(CAM_norm_exposure,`Feldspar signal` == "IR50"),
              method = "lm", se=FALSE, formula = y ~ poly(x,1), colour="#FEE391") +
  stat_smooth(data=filter(CAM_norm_exposure,`Feldspar signal` == "pIRIR150"),
              method = "lm", se=FALSE, formula = y ~ poly(x,1), colour="#FB9A29") +
  stat_smooth(data=filter(CAM_norm_exposure,`Feldspar signal` == "pIRIR225"),
              method = "lm", se=FALSE, formula = y ~ poly(x,1), colour="#CC4C02") +
  stat_smooth(data=filter(CAM_norm_exposure,`Feldspar signal` == "pIRIR290"),
              method = "lm", se=FALSE, formula = y ~ poly(x,1), colour="#8B0000") +
  scale_x_continuous(expand = c(0.01, 0.01), limits=c(0,1100486773)) +
  scale_y_continuous(expand = c(0.01, 0.01)) +
  xlab("Cumulative energy [J/m^2]") +
  ylab("Normalized CAM") +
  annotate("text", x=CAM_norm_exposure$cum_energy, y=1.3, label=paste("#", CAM_norm_exposure$label, sep=""), size=3.5, colour="gray40", angle=90) +
  annotate("text", x=8e+08, y=1.3, label="NCL-1422 #XXX", size=3.5, colour="gray40") +
  theme(panel.border = element_rect(colour = "black", fill=NA, linewidth = 1),
        panel.background = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.text.x=element_text(size = 15),
        axis.ticks.x=element_blank(),
        legend.position = "top",
        axis.text.y=element_text(size=15),
        axis.title.x=element_text(size=15),
        axis.title.y=element_text(size=15),
        axis.ticks = element_line(size=1))
ggsave("Figure9_normalizedCAM_vs_cumlight.png",plot=last_plot(), width=10, height=10)

